@@ -5,7 +5,12 @@ export { default as refreshIntervalAtom } from './refreshIntervalAtom';
 export { default as cloudServicesAtom } from './cloudServicesAtom';
 export { default as acknowledgementAtom } from './acknowledgementAtom';
 export { default as resourceStorageOptimizationModeAtom } from './resourceStorageOptimizationMode';
-export { ThemeMode } from './types';
+export { default as platformNameAtom } from './platformNameAtom';
+export { ThemeMode, ListingVariant } from './types';
+export {
+  platformFeaturesAtom,
+  featureFlagsDerivedAtom
+} from './platformFeaturesAtom';
 
 export type {
   User,
@@ -16,4 +21,6 @@ export type {
   CloudServices,
   Acknowledgement,
   Acl,
+  FeatureFlags,
+  PlatformFeatures
 } from './types';
