@@ -1,4 +1,9 @@
-import React from 'react';
+import { Dispatch, SetStateAction } from 'react';
+
+export enum ListingVariant {
+  compact = 'compact',
+  extended = 'extended'
+}
 
 export interface User {
   alias: string;
@@ -9,16 +14,17 @@ export interface User {
   themeMode?: ThemeMode;
   timezone: string;
   use_deprecated_pages: boolean;
+  user_interface_density: ListingVariant;
 }
 
 export enum ThemeMode {
   dark = 'dark',
-  light = 'light',
+  light = 'light'
 }
 
 export interface CloudServices {
   areCloudServicesEnabled: boolean;
-  setAreCloudServicesEnabled: React.Dispatch<React.SetStateAction<boolean>>;
+  setAreCloudServicesEnabled: Dispatch<SetStateAction<boolean>>;
 }
 
 export interface Acknowledgement {
@@ -60,3 +66,16 @@ export interface Downtime {
   fixed: boolean;
   with_services: boolean;
 }
+
+export interface FeatureFlags {
+  adExclusionPeriods?: boolean;
+  dashboard?: boolean;
+  notification?: boolean;
+  resourceStatusTreeView?: boolean;
+  vault?: boolean;
+}
+
+export interface PlatformFeatures {
+  featureFlags: FeatureFlags;
+  isCloudPlatform: boolean;
+}
