@@ -1,3 +1,5 @@
+/* eslint-disable no-underscore-dangle */
+/* eslint-disable no-undef */
 // import '@testing-library/jest-dom/extend-expect';
 import i18n from 'i18next';
 import { initReactI18next } from 'react-i18next';
@@ -6,7 +8,7 @@ import fetchMock from 'jest-fetch-mock';
 const mockedMatchMedia = () => ({
   addListener: () => {},
   matches: false,
-  removeListener: () => {},
+  removeListener: () => {}
 });
 
 window.matchMedia = window.matchMedia || mockedMatchMedia;
@@ -14,10 +16,10 @@ window.matchMedia = window.matchMedia || mockedMatchMedia;
 document.createRange = () => ({
   commonAncestorContainer: {
     nodeName: 'BODY',
-    ownerDocument: document,
+    ownerDocument: document
   },
   setEnd: () => {},
-  setStart: () => {},
+  setStart: () => {}
 });
 
 global.IntersectionObserver = class IntersectionObserver {
@@ -43,9 +45,28 @@ Object.defineProperty(window, 'matchMedia', {
     media: query,
     onchange: null,
     removeEventListener: jest.fn(),
-    removeListener: jest.fn(),
+    removeListener: jest.fn()
   })),
-  writable: true,
+  writable: true
+});
+
+Object.defineProperty(Image.prototype, 'onload', {
+  get() {
+    return this._onload;
+  },
+  set(onload) {
+    onloadRef = onload;
+    this._onload = onload;
+  }
+});
+Object.defineProperty(Image.prototype, 'onerror', {
+  get() {
+    return this._onerror;
+  },
+  set(onerror) {
+    onerrorRef = onerror;
+    this._onerror = onerror;
+  }
 });
 
 i18n.use(initReactI18next).init({
@@ -53,13 +74,13 @@ i18n.use(initReactI18next).init({
   keySeparator: false,
   lng: 'en',
   nsSeparator: false,
-  resources: {},
+  resources: {}
 });
 
 window.Image = () => ({
   onerror: () => {},
   onload: () => {},
-  src: null,
+  src: null
 });
 
 fetchMock.enableMocks();
