@@ -3,13 +3,15 @@ import { makeStyles } from 'tss-react/mui';
 import {
   IconButton as MuiIconButton,
   IconButtonProps,
-  Tooltip,
+  Tooltip
 } from '@mui/material';
 
+import getNormalizedId from '../../utils/getNormalizedId';
+
 const useStyles = makeStyles()((theme) => ({
   button: {
-    padding: theme.spacing(0.25),
-  },
+    padding: theme.spacing(0.25)
+  }
 }));
 
 type Props = {
@@ -17,23 +19,39 @@ type Props = {
   className?: string;
   onClick: (event) => void;
   title?: string;
+  tooltipPlacement?:
+    | 'bottom'
+    | 'left'
+    | 'right'
+    | 'top'
+    | 'bottom-end'
+    | 'bottom-start'
+    | 'left-end'
+    | 'left-start'
+    | 'right-end'
+    | 'right-start'
+    | 'top-end'
+    | 'top-start';
 } & IconButtonProps;
 
 const IconButton = ({
   title = '',
   ariaLabel,
   className,
+  tooltipPlacement,
   ...props
 }: Props): JSX.Element => {
   const { classes, cx } = useStyles();
 
   return (
-    <Tooltip title={title}>
+    <Tooltip placement={tooltipPlacement} title={title}>
       <span aria-label={undefined}>
         <MuiIconButton
           aria-label={ariaLabel}
           className={cx(classes.button, className)}
           color="primary"
+          data-testid={ariaLabel}
+          id={getNormalizedId(ariaLabel || '')}
           {...props}
         />
       </span>
