@@ -2,7 +2,7 @@ import DialogContentText from '@mui/material/DialogContentText';
 
 import Dialog, { Props as DialogProps } from '..';
 
-type Props = DialogProps & { labelMessage: string };
+type Props = DialogProps & { labelMessage?: string | null };
 
 const Confirm = ({ labelMessage, ...rest }: Props): JSX.Element => (
   <Dialog {...rest}>
