@@ -1,12 +1,13 @@
-import { FC, Suspense } from 'react';
+import { memo } from 'react';
 
 import { makeStyles } from 'tss-react/mui';
+import { equals, isNil } from 'ramda';
 
 import { useLoadImage } from './useLoadImage';
 
 export enum ImageVariant {
   Contain = 'contain',
-  Cover = 'cover',
+  Cover = 'cover'
 }
 
 interface Props {
@@ -24,22 +25,25 @@ const useStyles = makeStyles<Pick<Props, 'width' | 'height' | 'variant'>>()(
     imageContent: {
       height,
       objectFit: variant,
-      width,
-    },
-  }),
+      width
+    }
+  })
 );
 
-const ImageContent: FC<Omit<Props, 'fallback'>> = ({
+const ImageContent = ({
   alt,
   className,
   height,
   width,
   imagePath,
   variant = ImageVariant.Cover,
-}) => {
+  fallback
+}: Props): JSX.Element => {
   const { classes, cx } = useStyles({ height, variant, width });
-  const image = useLoadImage({ alt, imageSrc: imagePath });
-  image.read();
+  const isImageLoaded = useLoadImage({ alt, imageSrc: imagePath });
+  if (!isImageLoaded) {
+    return fallback;
+  }
 
   return (
     <img
@@ -50,12 +54,12 @@ const ImageContent: FC<Omit<Props, 'fallback'>> = ({
   );
 };
 
-const SuspendedImage: FC<Props> = ({ fallback, ...props }) => {
-  return (
-    <Suspense fallback={fallback}>
-      <ImageContent {...props} />
-    </Suspense>
-  );
+const SuspendedImage = ({ imagePath, ...props }: Props): JSX.Element | null => {
+  if (isNil(imagePath)) {
+    return null;
+  }
+
+  return <ImageContent {...props} imagePath={imagePath} />;
 };
 
-export default SuspendedImage;
+export default memo(SuspendedImage, equals);
