@@ -1,13 +1,15 @@
 /* eslint-disable react/prop-types */
-import { useState } from 'react';
+import { React, useState } from 'react';
 
 import { ComponentMeta, ComponentStory } from '@storybook/react';
-import { prop } from 'ramda';
+import { equals, prop } from 'ramda';
 import { makeStyles } from 'tss-react/mui';
 
 import { Button } from '@mui/material';
 import { grey } from '@mui/material/colors';
 
+import { ListingVariant } from '@centreon/ui-context';
+
 import { ListingProps } from '..';
 
 import { Column, ColumnType } from './models';
@@ -20,16 +22,16 @@ export default {
     currentPage: { control: 'number' },
     limit: { control: 'number' },
     loading: { control: 'boolean' },
-    totalRows: { control: 'number' },
+    totalRows: { control: 'number' }
   },
   component: Listing,
-  title: 'Listing',
+  title: 'Listing'
 } as ComponentMeta<typeof Listing>;
 
 const useStyles = makeStyles()((theme) => ({
   listing: {
-    backgroundColor: theme.palette.background.default,
-  },
+    backgroundColor: theme.palette.background.default
+  }
 }));
 
 const ComponentColumn = ({ row, isSelected }): JSX.Element => (
@@ -51,20 +53,20 @@ const defaultColumns = [
     getFormattedString: ({ name }): string => name,
     id: 'name',
     label: 'Name',
-    type: ColumnType.string,
+    type: ColumnType.string
   },
   {
     getFormattedString: ({ description }): string => description,
     id: 'description',
     label: 'Description',
-    type: ColumnType.string,
+    type: ColumnType.string
   },
   {
     Component: ComponentColumn,
     id: '#',
     label: 'Custom',
-    type: ColumnType.component,
-  },
+    type: ColumnType.component
+  }
 ];
 
 const columnsWithShortLabel = [
@@ -72,21 +74,21 @@ const columnsWithShortLabel = [
     getFormattedString: ({ name }): string => name,
     id: 'name',
     label: 'Name',
-    type: ColumnType.string,
+    type: ColumnType.string
   },
   {
     getFormattedString: ({ description }): string => description,
     id: 'description',
     label: 'Description',
     shortLabel: 'D',
-    type: ColumnType.string,
+    type: ColumnType.string
   },
   {
     Component: ComponentColumn,
     id: '#',
     label: 'Custom',
-    type: ColumnType.component,
-  },
+    type: ColumnType.component
+  }
 ];
 
 const tenElements = new Array(10).fill(0);
@@ -107,31 +109,32 @@ const listing = [...tenElements].map((_, index) => ({
   disableRow: index % 5 === 0,
   id: index,
   name: `E${index}`,
-  selected: index % 3 === 0,
+  selected: index % 3 === 0
 }));
 
 const rowColorConditions = [
   {
     color: grey[100],
     condition: ({ active }): boolean => !active,
-    name: 'inactive',
-  },
+    name: 'inactive'
+  }
 ];
 
 const predefinedRowsSelection = [
   {
     label: 'active',
-    rowCondition: (row): boolean => row.active,
+    rowCondition: (row): boolean => row.active
   },
   {
     label: 'not active',
-    rowCondition: (row): boolean => !row.active,
-  },
+    rowCondition: (row): boolean => !row.active
+  }
 ];
 
 const Story = ({
   columns = defaultColumns,
   checkable = true,
+  viewerModeConfiguration,
   ...props
 }: Omit<ListingProps<Entity>, 'columns'> & {
   columns?: Array<Column>;
@@ -153,6 +156,7 @@ const Story = ({
         rows={listing}
         selectedRows={selected}
         totalRows={listing.length}
+        viewerModeConfiguration={viewerModeConfiguration}
         onSelectRows={setSelected}
         {...props}
       />
@@ -162,6 +166,23 @@ const Story = ({
 
 export const normal = (): JSX.Element => <Story />;
 
+export const WithSpecifiedViewMode = (): JSX.Element => {
+  const [viewMode, setViewMode] = useState(ListingVariant.extended);
+  const newViewMode = equals(viewMode, ListingVariant.compact)
+    ? ListingVariant.extended
+    : ListingVariant.compact;
+
+  return (
+    <Story
+      viewMode={viewMode}
+      viewerModeConfiguration={{
+        onClick: () => setViewMode(newViewMode),
+        title: viewMode
+      }}
+    />
+  );
+};
+
 export const loadingWithNoData = (): JSX.Element => {
   return <Story loading rows={[]} totalRows={0} />;
 };
@@ -189,27 +210,27 @@ const editableColumns = [
     getFormattedString: ({ name }): string => name,
     id: 'name',
     label: 'Name',
-    type: ColumnType.string,
+    type: ColumnType.string
   },
   {
     getFormattedString: ({ description }): string => description,
     id: 'description',
     label: 'Description',
-    type: ColumnType.string,
+    type: ColumnType.string
   },
   {
     Component: ComponentColumn,
     id: '#',
     label: 'Custom',
-    type: ColumnType.component,
+    type: ColumnType.component
   },
   {
     disabled: true,
     getFormattedString: ({ name }): string => name,
     id: 'disabled_name',
     label: 'Disabled Name',
-    type: ColumnType.string,
-  },
+    type: ColumnType.string
+  }
 ];
 
 const ListingWithEditableColumns = (): JSX.Element => {
@@ -226,7 +247,7 @@ const ListingWithEditableColumns = (): JSX.Element => {
     <Story
       columnConfiguration={{
         selectedColumnIds,
-        sortable: true,
+        sortable: true
       }}
       columns={editableColumns}
       onResetColumns={resetColumns}
@@ -257,5 +278,5 @@ PlaygroundListing.args = {
   currentPage: 1,
   limit: 10,
   loading: false,
-  totalRows: 10,
+  totalRows: 10
 };
