@@ -9,9 +9,9 @@ interface Props {
 const useDebounce = ({
   functionToDebounce,
   wait,
-  memoProps = [],
+  memoProps = []
 }: Props): ((...args) => void) => {
-  const timeoutRef = useRef<NodeJS.Timeout | null>(null);
+  const timeoutRef = useRef<number | null>(null);
 
   return useCallback((...args): void => {
     if (timeoutRef.current) {
