@@ -301,7 +301,10 @@ class CheckController extends AbstractController
          * @var Contact $contact
          */
         $contact = $this->getUser();
-        if (!$contact->isAdmin() && !$contact->hasRole(Contact::ROLE_SERVICE_CHECK)) {
+        if (
+            ! $contact->isAdmin()
+            && !$contact->hasRole(Contact::ROLE_SERVICE_CHECK)
+        ) {
             return $this->view(null, Response::HTTP_UNAUTHORIZED);
         }
 
@@ -446,12 +449,12 @@ class CheckController extends AbstractController
          * @var CheckRequest $checkRequest
          */
         $checkRequest = $serializer->deserialize(
-            (string)$request->getContent(),
+            (string) $request->getContent(),
             CheckRequest::class,
             'json'
         );
 
-        $checkRequest->setCheck((new Check())->setCheckTime(new DateTime()));
+        $checkRequest->getCheck()->setCheckTime(new DateTime());
 
         foreach ($checkRequest->getResources() as $resource) {
             // start check process
