@@ -1,13 +1,13 @@
 <?php
 
 /*
- * Copyright 2005 - 2020 Centreon (https://www.centreon.com/)
+ * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ * https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,17 +18,53 @@
  * For more information : contact@centreon.com
  *
  */
+
 declare(strict_types=1);
 
 namespace Centreon\Domain\Common\Assertion;
 
+use Assert\Assertion as Assert;
+
 /**
- * This class is designed to contain all assertion exceptions
- *
- * @package Centreon\Domain\Common\Assertion
+ * This class is designed to contain all assertion exceptions.
  */
-class AssertionException extends \InvalidArgumentException
+class AssertionException extends \Assert\InvalidArgumentException
 {
+    public const INVALID_EMAIL = Assert::INVALID_EMAIL;
+    public const INVALID_GREATER_OR_EQUAL = Assert::INVALID_GREATER_OR_EQUAL;
+    public const INVALID_IP = Assert::INVALID_IP;
+    public const INVALID_IP_OR_DOMAIN = 1002;
+    public const INVALID_MAX = Assert::INVALID_MAX;
+    public const INVALID_MAX_DATE = 1001;
+    public const INVALID_MAX_LENGTH = Assert::INVALID_MAX_LENGTH;
+    public const INVALID_MIN = Assert::INVALID_MIN;
+    public const INVALID_MIN_LENGTH = Assert::INVALID_MIN_LENGTH;
+    public const INVALID_RANGE = Assert::INVALID_RANGE;
+    public const INVALID_REGEX = Assert::INVALID_REGEX;
+    public const INVALID_CHOICE = Assert::INVALID_CHOICE;
+    public const VALUE_EMPTY = Assert::VALUE_EMPTY;
+    public const VALUE_NULL = Assert::VALUE_NULL;
+
+    /**
+     * The extended constructor is here only to enforce the types used
+     * and set a default `int $code = 0` for child classes.
+     *
+     * @param string $message
+     * @param int $code
+     * @param string|null $propertyPath
+     * @param mixed|null $value
+     * @param array<string, mixed> $constraints
+     */
+    public function __construct(
+        string $message,
+        int $code = 0,
+        ?string $propertyPath = null,
+        mixed $value = null,
+        array $constraints = []
+    ) {
+        parent::__construct($message, $code, $propertyPath, $value, $constraints);
+    }
+
     /**
      * Exception when the value of the string is longer than the expected number of characters.
      *
@@ -36,10 +72,15 @@ class AssertionException extends \InvalidArgumentException
      * @param int $valueLength Length of the tested value
      * @param int $maxLength Maximum length of the expected value in characters
      * @param string|null $propertyPath Property's path (ex: Host::name)
+     *
      * @return self
      */
-    public static function maxLength(string $value, int $valueLength, int $maxLength, string $propertyPath = null): self
-    {
+    public static function maxLength(
+        string $value,
+        int $valueLength,
+        int $maxLength,
+        ?string $propertyPath = null
+    ): self {
         return new self(
             sprintf(
                 _(
@@ -50,7 +91,10 @@ class AssertionException extends \InvalidArgumentException
                 $value,
                 $maxLength,
                 $valueLength
-            )
+            ),
+            self::INVALID_MAX_LENGTH,
+            $propertyPath,
+            $value
         );
     }
 
@@ -61,10 +105,15 @@ class AssertionException extends \InvalidArgumentException
      * @param int $valueLength Length of the tested value
      * @param int $minLength Minimum length of the expected value in characters
      * @param string|null $propertyPath Property's path (ex: Host::name)
+     *
      * @return self
      */
-    public static function minLength(string $value, int $valueLength, int $minLength, string $propertyPath = null): self
-    {
+    public static function minLength(
+        string $value,
+        int $valueLength,
+        int $minLength,
+        ?string $propertyPath = null
+    ): self {
         return new self(
             sprintf(
                 _(
@@ -75,19 +124,38 @@ class AssertionException extends \InvalidArgumentException
                 $value,
                 $minLength,
                 $valueLength
-            )
+            ),
+            self::INVALID_MIN_LENGTH,
+            $propertyPath,
+            $value
         );
     }
 
+    /**
+     * Exception when the value of the integer is < 1.
+     *
+     * @param positive-int $value Tested value
+     * @param string|null $propertyPath Property's path (ex: Host::maxCheckAttempts)
+     *
+     * @return self
+     */
+    public static function positiveInt(int $value, ?string $propertyPath = null): self
+    {
+        return self::min($value, 1, $propertyPath);
+    }
+
     /**
      * Exception when the value of the integer is less than the expected value.
      *
+     * Same as {@see self::greaterOrEqualThan()} but with a different message.
+     *
      * @param int $value Tested value
      * @param int $minValue Minimum value
      * @param string|null $propertyPath Property's path (ex: Host::maxCheckAttempts)
+     *
      * @return self
      */
-    public static function min(int $value, int $minValue, string $propertyPath = null): self
+    public static function min(int $value, int $minValue, ?string $propertyPath = null): self
     {
         return new self(
             sprintf(
@@ -95,7 +163,10 @@ class AssertionException extends \InvalidArgumentException
                 $propertyPath,
                 $value,
                 $minValue
-            )
+            ),
+            self::INVALID_MIN,
+            $propertyPath,
+            $value
         );
     }
 
@@ -105,9 +176,10 @@ class AssertionException extends \InvalidArgumentException
      * @param int $value Tested value
      * @param int $maxValue Maximum value
      * @param string|null $propertyPath Property's path (ex: Host::maxCheckAttempts)
+     *
      * @return self
      */
-    public static function max(int $value, int $maxValue, string $propertyPath = null): self
+    public static function max(int $value, int $maxValue, ?string $propertyPath = null): self
     {
         return new self(
             sprintf(
@@ -115,7 +187,10 @@ class AssertionException extends \InvalidArgumentException
                 $propertyPath,
                 $value,
                 $maxValue
-            )
+            ),
+            self::INVALID_MAX,
+            $propertyPath,
+            $value
         );
     }
 
@@ -124,48 +199,64 @@ class AssertionException extends \InvalidArgumentException
      *
      * @param string $value Tested value
      * @param string|null $propertyPath Property's path (ex: Host::maxCheckAttempts)
+     *
      * @return self
      */
-    public static function email(string $value, string $propertyPath = null): self
+    public static function email(string $value, ?string $propertyPath = null): self
     {
         return new self(
             sprintf(
                 _('[%s] The value "%s" was expected to be a valid e-mail address'),
                 $propertyPath,
                 $value
-            )
+            ),
+            self::INVALID_EMAIL,
+            $propertyPath,
+            $value
         );
     }
 
     /**
      * Exception when the value of the date is higher than the expected date.
      *
-     * @param \DateTime $date Tested date
-     * @param \DateTime $maxDate Maximum date
+     * @param \DateTimeInterface $date Tested date
+     * @param \DateTimeInterface $maxDate Maximum date
      * @param string|null $propertyPath Property's path (ex: Host::maxCheckAttempts)
+     *
      * @return self
      */
-    public static function maxDate(\DateTime $date, \DateTime $maxDate, string $propertyPath = null): self
-    {
+    public static function maxDate(
+        \DateTimeInterface $date,
+        \DateTimeInterface $maxDate,
+        ?string $propertyPath = null
+    ): self {
+        $value = $date->format('c');
+
         return new self(
             sprintf(
                 _('[%s] The date "%s" was expected to be at most %s'),
                 $propertyPath,
-                $date->format('c'),
+                $value,
                 $maxDate->format('c')
-            )
+            ),
+            self::INVALID_MAX_DATE,
+            $propertyPath,
+            $value
         );
     }
 
     /**
      * Exception when the value of the integer is less than the expected value.
      *
+     * Same as {@see self::min()} but with a different message.
+     *
      * @param int $value Tested value
      * @param int $limit Limit value
      * @param string|null $propertyPath Property's path (ex: Host::maxCheckAttempts)
+     *
      * @return self
      */
-    public static function greaterOrEqualThan(int $value, int $limit, string $propertyPath = null): self
+    public static function greaterOrEqualThan(int $value, int $limit, ?string $propertyPath = null): self
     {
         return new self(
             sprintf(
@@ -173,7 +264,10 @@ class AssertionException extends \InvalidArgumentException
                 $propertyPath,
                 $value,
                 $limit
-            )
+            ),
+            self::INVALID_GREATER_OR_EQUAL,
+            $propertyPath,
+            $value
         );
     }
 
@@ -181,15 +275,37 @@ class AssertionException extends \InvalidArgumentException
      * Exception when the value is empty.
      *
      * @param string|null $propertyPath Property's path (ex: Host::name)
+     *
      * @return self
      */
-    public static function notEmpty(string $propertyPath = null): self
+    public static function notEmpty(?string $propertyPath = null): self
     {
         return new self(
             sprintf(
                 _('[%s] The value is empty, but non empty value was expected'),
                 $propertyPath
-            )
+            ),
+            self::VALUE_EMPTY,
+            $propertyPath
+        );
+    }
+
+    /**
+     * Exception when the string is empty.
+     *
+     * @param string|null $propertyPath Property's path (ex: Host::name)
+     *
+     * @return self
+     */
+    public static function notEmptyString(?string $propertyPath = null): self
+    {
+        return new self(
+            sprintf(
+                _('[%s] The string is empty, but non empty string was expected'),
+                $propertyPath
+            ),
+            self::VALUE_EMPTY,
+            $propertyPath
         );
     }
 
@@ -197,15 +313,18 @@ class AssertionException extends \InvalidArgumentException
      * Exception when the value is null.
      *
      * @param string|null $propertyPath Property's path (ex: Host::name)
+     *
      * @return self
      */
-    public static function notNull(string $propertyPath = null): self
+    public static function notNull(?string $propertyPath = null): self
     {
         return new self(
             sprintf(
                 _('[%s] The value is null, but non null value was expected'),
                 $propertyPath
-            )
+            ),
+            self::VALUE_NULL,
+            $propertyPath
         );
     }
 
@@ -215,9 +334,10 @@ class AssertionException extends \InvalidArgumentException
      * @param mixed $value
      * @param mixed[] $expectedValues
      * @param string|null $propertyPath Property's path (ex: Host::name)
+     *
      * @return self
      */
-    public static function inArray($value, array $expectedValues, string $propertyPath = null): self
+    public static function inArray(mixed $value, array $expectedValues, ?string $propertyPath = null): self
     {
         return new self(
             sprintf(
@@ -225,7 +345,39 @@ class AssertionException extends \InvalidArgumentException
                 $propertyPath,
                 $value,
                 implode('|', $expectedValues)
-            )
+            ),
+            self::INVALID_CHOICE,
+            $propertyPath,
+            $value
+        );
+    }
+
+    /**
+     * Exception when the value is not in the range.
+     *
+     * @param int|float $value
+     * @param int|float $minValue
+     * @param int|float $maxValue
+     * @param string|null $propertyPath
+     *
+     * @return self
+     */
+    public static function range(
+        int|float $value,
+        int|float $minValue,
+        int|float $maxValue,
+        ?string $propertyPath = null
+    ): self {
+        return new self(
+            sprintf(
+                _('Number "%s" was expected to be at least "%d" and at most "%d"'),
+                $value,
+                $minValue,
+                $maxValue
+            ),
+            self::INVALID_RANGE,
+            $propertyPath,
+            $value
         );
     }
 
@@ -234,16 +386,20 @@ class AssertionException extends \InvalidArgumentException
      *
      * @param string $value Tested value
      * @param string|null $propertyPath Property's path (ex: Host::maxCheckAttempts)
+     *
      * @return self
      */
-    public static function ipOrDomain(string $value, string $propertyPath = null): self
+    public static function ipOrDomain(string $value, ?string $propertyPath = null): self
     {
         return new self(
             sprintf(
                 _('[%s] The value "%s" was expected to be a valid ip address or domain name'),
                 $propertyPath,
                 $value
-            )
+            ),
+            self::INVALID_IP_OR_DOMAIN,
+            $propertyPath,
+            $value
         );
     }
 
@@ -253,17 +409,21 @@ class AssertionException extends \InvalidArgumentException
      * @param string $value
      * @param string $pattern
      * @param string|null $propertyPath
+     *
      * @return self
      */
-    public static function matchRegex(string $value, string $pattern, string $propertyPath = null): self
+    public static function matchRegex(string $value, string $pattern, ?string $propertyPath = null): self
     {
         return new self(
             sprintf(
-                _('[%s] The value (%s) doesn\'t match the regex \'%s\''),
+                _("[%s] The value (%s) doesn't match the regex '%s'"),
                 $propertyPath,
                 $value,
                 $pattern
-            )
+            ),
+            self::INVALID_REGEX,
+            $propertyPath,
+            $value
         );
     }
 
@@ -272,16 +432,20 @@ class AssertionException extends \InvalidArgumentException
      *
      * @param string $value Tested value
      * @param string|null $propertyPath Property's path (ex: Host::maxCheckAttempts)
+     *
      * @return self
      */
-    public static function ipAddressNotValid(string $value, string $propertyPath = null): self
+    public static function ipAddressNotValid(string $value, ?string $propertyPath = null): self
     {
         return new self(
             sprintf(
-                _('[%s] The value \'%s\' was expected to be a valid ip address'),
+                _("[%s] The value '%s' was expected to be a valid ip address"),
                 $propertyPath,
                 $value
-            )
+            ),
+            self::INVALID_IP,
+            $propertyPath,
+            $value
         );
     }
 }
