@@ -27,24 +27,22 @@ use Symfony\Component\Routing\RouterInterface;
 use Symfony\Component\Routing\Matcher\RequestMatcherInterface;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\HttpKernel\CacheWarmer\WarmableInterface;
-use Symfony\Component\Routing\Generator\UrlGeneratorInterface;
 
 /**
  * Override symfony router to generate base URI
  */
-class Router implements RouterInterface, RequestMatcherInterface, WarmableInterface, UrlGeneratorInterface
+class Router implements RouterInterface, RequestMatcherInterface, WarmableInterface
 {
     use HttpUrlTrait;
 
     /**
      * @var RouterInterface
      */
-    private $router;
-
+    private RouterInterface $router;
     /**
      * @var RequestMatcherInterface
      */
-    private $requestMatcher;
+    private RequestMatcherInterface $requestMatcher;
 
     /**
      * MyRouter constructor.
