@@ -29,12 +29,11 @@ use Centreon\Infrastructure\Service\Exception\NotFoundException;
 use Core\Security\Authentication\Application\Provider\ProviderAuthenticationInterface;
 use Core\Security\Authentication\Application\UseCase\Login\LoginRequest;
 use Core\Security\Authentication\Domain\Exception\SSOAuthenticationException;
-use Core\Security\Authentication\Domain\Exception\SSOMissingLoginAttributeException;
 use Core\Security\Authentication\Domain\Model\AuthenticationTokens;
 use Core\Security\Authentication\Domain\Model\NewProviderToken;
-use Core\Security\Authentication\Domain\Model\ProviderToken;
 use Core\Security\Authentication\Domain\Provider\WebSSOProvider;
 use Core\Security\ProviderConfiguration\Domain\Model\Configuration;
+use Core\Security\ProviderConfiguration\Domain\Model\Provider;
 use Core\Security\ProviderConfiguration\Domain\WebSSO\Model\CustomConfiguration;
 use DateInterval;
 use DateTimeImmutable;
@@ -93,7 +92,8 @@ class WebSSO implements ProviderAuthenticationInterface
             'show_deprecated_pages' => $user->isUsingDeprecatedPages(),
             'reach_api' => $user->hasAccessToApiConfiguration() ? 1 : 0,
             'reach_api_rt' => $user->hasAccessToApiRealTime() ? 1 : 0,
-            'contact_theme' => $user->getTheme() ?? 'light'
+            'contact_theme' => $user->getTheme() ?? 'light',
+            'auth_type' => Provider::WEB_SSO
         ];
 
         $this->provider->setLegacySession(new \Centreon($sessionUserInfos));
@@ -221,6 +221,10 @@ class WebSSO implements ProviderAuthenticationInterface
     {
         /** @var CustomConfiguration $customConfiguration */
         $customConfiguration = $this->getConfiguration()->getCustomConfiguration();
+        if (!$this->getConfiguration()->isActive()) {
+            return;
+        }
+
         $this->info('Validating login header attribute');
         if (!array_key_exists($customConfiguration->getLoginHeaderAttribute(), $_SERVER)) {
             $this->error('login header attribute not found in server environment', [
@@ -320,4 +324,14 @@ class WebSSO implements ProviderAuthenticationInterface
     {
         return [];
     }
+
+    public function getAclConditionsMatches(): array
+    {
+        return [];
+    }
+
+    public function getUserContactGroups(): array
+    {
+        return [];
+    }
 }
