@@ -47,7 +47,8 @@ final class FindUsers
         private readonly ReadUserRepositoryInterface $readUserRepository,
         private readonly ReadAccessGroupRepositoryInterface $readAccessGroupRepository,
         private readonly ContactInterface $user,
-        private readonly RequestParametersInterface $requestParameters
+        private readonly RequestParametersInterface $requestParameters,
+        private readonly bool $isCloudPlatform,
     ) {
     }
 
@@ -57,7 +58,7 @@ final class FindUsers
     public function __invoke(FindUsersPresenterInterface $presenter): void
     {
         try {
-            if ($this->user->isAdmin()) {
+            if ($this->hasAccessToAllUsers()) {
                 $users = $this->readUserRepository->findAllByRequestParameters($this->requestParameters);
             } else {
                 if (
@@ -69,12 +70,11 @@ final class FindUsers
                         ['user_id' => $this->user->getId()]
                     );
                     $presenter->presentResponse(
-                        new ForbiddenResponse(UserException::accessNotAllowed()->getMessage())
+                        new ForbiddenResponse(UserException::accessNotAllowed())
                     );
 
                     return;
                 }
-                $this->accessGroups = $this->readAccessGroupRepository->findByContact($this->user);
                 $users = $this->readUserRepository->findByAccessGroupsAndRequestParameters(
                     $this->accessGroups,
                     $this->requestParameters
@@ -87,7 +87,7 @@ final class FindUsers
             $this->error($ex->getMessage(), ['trace' => $ex->getTraceAsString()]);
         } catch (\Throwable $ex) {
             $presenter->presentResponse(
-                new ErrorResponse(UserException::errorWhileSearching($ex)->getMessage())
+                new ErrorResponse(UserException::errorWhileSearching($ex))
             );
             $this->error($ex->getMessage(), ['trace' => $ex->getTraceAsString()]);
         }
@@ -114,4 +114,15 @@ final class FindUsers
 
         return $response;
     }
+
+    private function hasAccessToAllUsers(): bool
+    {
+        if ($this->user->isAdmin()) {
+            return true;
+        }
+        $this->accessGroups = $this->readAccessGroupRepository->findByContact($this->user);
+        $accessGroupNames = array_map(fn(AccessGroup $accessGroup): string => $accessGroup->getName(), $this->accessGroups);
+
+        return ($this->isCloudPlatform && in_array('customer_admin_acl', $accessGroupNames, true));
+    }
 }
