@@ -397,11 +397,13 @@ class CentreonConfigPoller
      */
     public function pollerGenerate($variables, $login, $password)
     {
-        $poller_id = $this->ensurePollerId($variables);
 
         $config_generate = new \Generate($this->dependencyInjector);
-        $config_generate->configPollerFromId($poller_id, $login);
 
+        $poller_id = $this->ensurePollerId($variables);
+        //sanitize poller id against traversal path vulnerability
+        $poller_id = basename($poller_id);
+        $config_generate->configPollerFromId($poller_id, $login);
         /* Change files owner */
         $apacheUser = $this->getApacheUser();
 
@@ -499,10 +501,18 @@ class CentreonConfigPoller
             /* Change files owner */
             if ($apacheUser != "") {
                 foreach (glob($Nagioscfg["cfg_dir"] . '/*.{json,cfg}', GLOB_BRACE) as $file) {
+                    //handle path traversal vulnerability
+                    if (strpos($file, '..') !== false) {
+                        throw new Exception('Path traversal found');
+                    }
                     @chown($file, $apacheUser);
                     @chgrp($file, $apacheUser);
                 }
                 foreach (glob($Nagioscfg["cfg_dir"] . "/*.DEBUG") as $file) {
+                    //handle path traversal vulnerability
+                    if (strpos($file, '..') !== false) {
+                        throw new Exception('Path traversal found');
+                    }
                     @chown($file, $apacheUser);
                     @chgrp($file, $apacheUser);
                 }
@@ -548,6 +558,10 @@ class CentreonConfigPoller
                 /* Change files owner */
                 if ($apacheUser != "") {
                     foreach (glob(rtrim($centreonBrokerDirCfg, "/") . "/" . "/*.{xml,json,cfg}", GLOB_BRACE) as $file) {
+                        //handle path traversal vulnerability
+                        if (strpos($file, '..') !== false) {
+                            throw new Exception('Path traversal found');
+                        }
                         @chown($file, $apacheUser);
                         @chgrp($file, $apacheUser);
                     }
@@ -684,6 +698,10 @@ class CentreonConfigPoller
             mkdir("{$trapdPath}/{$pollerId}");
         }
         $filename = "{$trapdPath}/{$pollerId}/centreontrapd.sdb";
+        //handle path traversal vulnerability
+        if (strpos($filename, '..') !== false) {
+            throw new Exception('Path traversal found');
+        }
         passthru("$centreonDir/bin/generateSqlLite '{$pollerId}' '{$filename}' 2>&1");
         exec("echo 'SYNCTRAP:" . $pollerId . "' >> " . $this->centcore_pipe, $stdout, $return);
         return $return;
@@ -715,4 +733,4 @@ class CentreonConfigPoller
         }
         return $pollerState;
     }
-}
+}
\ No newline at end of file
