@@ -1,6 +1,6 @@
 import userEvent from '@testing-library/user-event';
-import axios from 'axios';
 import { head, last } from 'ramda';
+import fetchMock from 'jest-fetch-mock';
 
 import { TestQueryProvider } from '@centreon/ui';
 import {
@@ -10,7 +10,7 @@ import {
   RenderResult,
   resetMocks,
   screen,
-  waitFor,
+  waitFor
 } from '@centreon/ui/src/testRenderer';
 
 import { Provider } from '../models';
@@ -18,78 +18,69 @@ import {
   accessGroupsEndpoint,
   authenticationProvidersEndpoint,
   contactGroupsEndpoint,
-  contactTemplatesEndpoint,
+  contactTemplatesEndpoint
 } from '../api/endpoints';
 import {
   labelDoYouWantToResetTheForm,
   labelReset,
   labelResetTheForm,
-  labelSave,
+  labelSave
 } from '../Local/translatedLabels';
 import { labelActivation } from '../translatedLabels';
-
 import {
   labelAclAccessGroup,
   labelApplyOnlyFirtsRole,
+  labelRolesAttributePath,
+  labelMixed,
+  labelGroupsAttributePath,
+  labelGroupValue,
+  labelEnableAutoImport,
+  labelEnableAutomaticManagement,
+  labelDeleteRelation,
+  labelEnableConditionsOnIdentityProvider,
+  labelConditionsAttributePath,
+  labelConditionValue,
+  labelContactGroup,
+  labelContactTemplate
+} from '../shared/translatedLabels';
+
+import {
   labelAuthorizationEndpoint,
   labelBaseUrl,
   labelBlacklistClientAddresses,
   labelClientID,
   labelClientSecret,
-  labelConditionsAttributePath,
-  labelConditionValue,
-  labelContactGroup,
-  labelContactTemplate,
   labelDefineOpenIDConnectConfiguration,
   labelDefineYourEndpoint,
-  labelDeleteRelation,
   labelDisableVerifyPeer,
   labelEmailAttributePath,
-  labelEnableAutoImport,
-  labelEnableAutoManagement,
-  labelEnableConditionsOnIdentityProvider,
   labelEnableOpenIDConnectAuthentication,
   labelEndSessionEndpoint,
   labelFullnameAttributePath,
-  labelGroupsAttributePath,
-  labelGroupValue,
   labelIntrospectionEndpoint,
   labelIntrospectionTokenEndpoint,
   labelInvalidIPAddress,
   labelInvalidURL,
   labelLoginAttributePath,
-  labelMixed,
   labelOpenIDConnectOnly,
   labelOther,
   labelRedirectUrl,
-  labelRolesAttributePath,
   labelScopes,
   labelTokenEndpoint,
   labelTrustedClientAddresses,
   labelUseBasicAuthenticatonForTokenEndpointAuthentication,
-  labelUserInformationEndpoint,
+  labelUserInformationEndpoint
 } from './translatedLabels';
 
 import OpenidConfigurationForm from '.';
 
-const mockedAxios = axios as jest.Mocked<typeof axios>;
-
 jest.mock('../logos/providerPadlock.svg');
 
-const cancelTokenRequestParam = { cancelToken: {} };
-
-const cancelTokenPutParams = {
-  ...cancelTokenRequestParam,
-  headers: {
-    'Content-Type': 'application/x-www-form-urlencoded',
-  },
-};
-
 const renderOpenidConfigurationForm = (): RenderResult =>
   render(
     <TestQueryProvider>
       <OpenidConfigurationForm />
-    </TestQueryProvider>,
+    </TestQueryProvider>
   );
 
 const retrievedOpenidConfiguration = {
@@ -99,10 +90,10 @@ const retrievedOpenidConfiguration = {
     blacklist_client_addresses: ['127.0.0.1'],
     endpoint: {
       custom_endpoint: null,
-      type: 'introspection_endpoint',
+      type: 'introspection_endpoint'
     },
     is_enabled: false,
-    trusted_client_addresses: ['127.0.0.1'],
+    trusted_client_addresses: ['127.0.0.1']
   },
   authentication_type: 'client_secret_post',
   authorization_endpoint: '/authorize',
@@ -119,10 +110,10 @@ const retrievedOpenidConfiguration = {
     attribute_path: 'group attribute path',
     endpoint: {
       custom_endpoint: '/group/endpoint',
-      type: 'custom_endpoint',
+      type: 'custom_endpoint'
     },
     is_enabled: true,
-    relations: [],
+    relations: []
   },
   introspection_token_endpoint: '/introspect',
   is_active: true,
@@ -134,32 +125,32 @@ const retrievedOpenidConfiguration = {
     attribute_path: 'role attribute path',
     endpoint: {
       custom_endpoint: '/role/endpoint',
-      type: 'custom_endpoint',
+      type: 'custom_endpoint'
     },
     is_enabled: false,
-    relations: [],
+    relations: []
   },
   token_endpoint: '/token',
   userinfo_endpoint: '/userinfo',
-  verify_peer: false,
+  verify_peer: false
 };
 
 const getRetrievedEntities = (label: string): unknown => ({
   meta: {
     limit: 10,
     page: 1,
-    total: 30,
+    total: 30
   },
   result: [
     {
       id: 1,
-      name: `${label} 1`,
+      name: `${label} 1`
     },
     {
       id: 2,
-      name: `${label} 2`,
-    },
-  ],
+      name: `${label} 2`
+    }
+  ]
 });
 
 const retrievedAccessGroups = getRetrievedEntities('Access Group');
@@ -168,33 +159,26 @@ const retrievedContactGroups = getRetrievedEntities('Contact Group');
 
 const mockGetBasicRequests = (): void => {
   resetMocks();
-  mockedAxios.get.mockReset();
-  mockedAxios.get.mockResolvedValue({
-    data: retrievedOpenidConfiguration,
+  mockResponseOnce({
+    data: retrievedOpenidConfiguration
   });
 };
 
 describe('Openid configuration form', () => {
   beforeEach(() => {
     mockGetBasicRequests();
-
-    mockedAxios.put.mockReset();
-    mockedAxios.put.mockResolvedValue({
-      data: {},
-    });
   });
 
   it('displays the form', async () => {
     renderOpenidConfigurationForm();
 
     expect(
-      screen.getByText(labelDefineOpenIDConnectConfiguration),
+      screen.getByText(labelDefineOpenIDConnectConfiguration)
     ).toBeInTheDocument();
 
     await waitFor(() => {
-      expect(mockedAxios.get).toHaveBeenCalledWith(
-        authenticationProvidersEndpoint(Provider.Openid),
-        cancelTokenRequestParam,
+      expect(getFetchCall(0)).toEqual(
+        authenticationProvidersEndpoint(Provider.Openid)
       );
     });
 
@@ -204,85 +188,85 @@ describe('Openid configuration form', () => {
 
     await waitFor(() => {
       expect(
-        screen.getByLabelText(labelEnableOpenIDConnectAuthentication),
+        screen.getByLabelText(labelEnableOpenIDConnectAuthentication)
       ).toBeChecked();
     });
 
     expect(screen.getByLabelText(labelOpenIDConnectOnly)).not.toBeChecked();
     expect(screen.getByLabelText(labelMixed)).toBeChecked();
     expect(
-      screen.getByLabelText(`${labelTrustedClientAddresses}`),
+      screen.getByLabelText(`${labelTrustedClientAddresses}`)
     ).toBeInTheDocument();
     expect(
-      screen.getByLabelText(`${labelBlacklistClientAddresses}`),
+      screen.getByLabelText(`${labelBlacklistClientAddresses}`)
     ).toBeInTheDocument();
     expect(screen.getAllByText('127.0.0.1')).toHaveLength(2);
     expect(screen.getByLabelText(labelBaseUrl)).toHaveValue(
-      'https://localhost:8080',
+      'https://localhost:8080'
     );
     expect(screen.getByLabelText(labelAuthorizationEndpoint)).toHaveValue(
-      '/authorize',
+      '/authorize'
     );
     expect(screen.getByLabelText(labelTokenEndpoint)).toHaveValue('/token');
     expect(screen.getByLabelText(labelIntrospectionTokenEndpoint)).toHaveValue(
-      '/introspect',
+      '/introspect'
     );
     expect(
-      screen.getByLabelText(labelUserInformationEndpoint),
+      screen.getByLabelText(labelUserInformationEndpoint)
     ).toBeInTheDocument();
     expect(screen.getByLabelText(labelEndSessionEndpoint)).toHaveValue(
-      '/logout',
+      '/logout'
     );
     expect(screen.getByLabelText(`${labelScopes}`)).toBeInTheDocument();
     expect(screen.getByText('openid')).toBeInTheDocument();
     expect(screen.getByLabelText(labelLoginAttributePath)).toHaveValue('sub');
     expect(screen.getByLabelText(labelClientID)).toHaveValue('client_id');
     expect(screen.getByLabelText(labelClientSecret)).toHaveValue(
-      'client_secret',
+      'client_secret'
     );
     expect(
       screen.getByLabelText(
-        labelUseBasicAuthenticatonForTokenEndpointAuthentication,
-      ),
+        labelUseBasicAuthenticatonForTokenEndpointAuthentication
+      )
     ).not.toBeChecked();
     expect(screen.getByLabelText(labelDisableVerifyPeer)).not.toBeChecked();
     expect(screen.getByLabelText(labelEnableAutoImport)).not.toBeChecked();
     expect(screen.getByLabelText(labelEmailAttributePath)).toHaveValue('email');
     expect(screen.getByLabelText(labelFullnameAttributePath)).toHaveValue(
-      'lastname',
+      'lastname'
     );
     expect(
-      screen.getByLabelText(labelEnableConditionsOnIdentityProvider),
+      screen.getByLabelText(labelEnableConditionsOnIdentityProvider)
     ).not.toBeChecked();
     expect(screen.getByLabelText(labelConditionsAttributePath)).toHaveValue(
-      'auth attribute path',
+      'auth attribute path'
     );
     expect(
-      head(screen.getAllByLabelText(labelIntrospectionEndpoint)),
+      head(screen.getAllByLabelText(labelIntrospectionEndpoint))
     ).toBeChecked();
     expect(head(screen.getAllByLabelText(labelConditionValue))).toHaveValue(
-      'authorized',
+      'authorized'
     );
     expect(
-      head(screen.getAllByLabelText(labelEnableAutoManagement)),
+      head(screen.getAllByLabelText(labelEnableAutomaticManagement))
     ).not.toBeChecked();
     expect(screen.getByLabelText(labelApplyOnlyFirtsRole)).toBeChecked();
     expect(screen.getByLabelText(labelRolesAttributePath)).toHaveValue(
-      'role attribute path',
+      'role attribute path'
     );
     expect(screen.getAllByLabelText(labelOther)[1]).toBeChecked();
     expect(head(screen.getAllByLabelText(labelDefineYourEndpoint))).toHaveValue(
-      '/role/endpoint',
+      '/role/endpoint'
     );
     expect(
-      last(screen.getAllByLabelText(labelEnableAutoManagement)),
+      last(screen.getAllByLabelText(labelEnableAutomaticManagement))
     ).toBeChecked();
     expect(screen.getByLabelText(labelGroupsAttributePath)).toHaveValue(
-      'group attribute path',
+      'group attribute path'
     );
     expect(last(screen.getAllByLabelText(labelOther))).toBeChecked();
     expect(last(screen.getAllByLabelText(labelDefineYourEndpoint))).toHaveValue(
-      '/group/endpoint',
+      '/group/endpoint'
     );
     expect(screen.getByLabelText(labelRedirectUrl)).toHaveValue('');
   });
@@ -291,9 +275,8 @@ describe('Openid configuration form', () => {
     renderOpenidConfigurationForm();
 
     await waitFor(() => {
-      expect(mockedAxios.get).toHaveBeenCalledWith(
-        authenticationProvidersEndpoint(Provider.Openid),
-        cancelTokenRequestParam,
+      expect(getFetchCall(0)).toEqual(
+        authenticationProvidersEndpoint(Provider.Openid)
       );
     });
 
@@ -303,7 +286,7 @@ describe('Openid configuration form', () => {
 
     userEvent.type(
       screen.getByLabelText(labelBaseUrl),
-      '{selectall}{backspace}invalid base url',
+      '{selectall}{backspace}invalid base url'
     );
     userEvent.tab();
 
@@ -313,25 +296,25 @@ describe('Openid configuration form', () => {
 
     userEvent.type(
       screen.getByLabelText(`${labelTrustedClientAddresses}`),
-      'invalid domain',
+      'invalid domain'
     );
     userEvent.keyboard('{Enter}');
 
     await waitFor(() => {
       expect(
-        screen.getByText(`invalid domain: ${labelInvalidIPAddress}`),
+        screen.getByText(`invalid domain: ${labelInvalidIPAddress}`)
       ).toBeInTheDocument();
     });
 
     userEvent.type(
       screen.getByLabelText(`${labelBlacklistClientAddresses}`),
-      '127.0.0.1111',
+      '127.0.0.1111'
     );
     userEvent.keyboard('{Enter}');
 
     await waitFor(() => {
       expect(
-        screen.getByText(`127.0.0.1111: ${labelInvalidIPAddress}`),
+        screen.getByText(`127.0.0.1111: ${labelInvalidIPAddress}`)
       ).toBeInTheDocument();
     });
 
@@ -343,13 +326,12 @@ describe('Openid configuration form', () => {
     renderOpenidConfigurationForm();
 
     mockResponseOnce({
-      data: retrievedContactGroups,
+      data: retrievedContactGroups
     });
 
     await waitFor(() => {
-      expect(mockedAxios.get).toHaveBeenCalledWith(
-        authenticationProvidersEndpoint(Provider.Openid),
-        cancelTokenRequestParam,
+      expect(getFetchCall(0)).toEqual(
+        authenticationProvidersEndpoint(Provider.Openid)
       );
     });
 
@@ -359,7 +341,7 @@ describe('Openid configuration form', () => {
 
     userEvent.type(
       screen.getByLabelText(labelBaseUrl),
-      '{selectall}{backspace}http://localhost:8081/login',
+      '{selectall}{backspace}http://localhost:8081/login'
     );
     userEvent.tab();
 
@@ -377,31 +359,32 @@ describe('Openid configuration form', () => {
 
     userEvent.type(
       head(screen.getAllByLabelText(labelGroupValue)) as HTMLElement,
-      'groupValue',
+      'groupValue'
     );
 
     userEvent.click(screen.getByText(labelSave));
 
     await waitFor(() => {
-      expect(mockedAxios.put).toHaveBeenCalledWith(
-        authenticationProvidersEndpoint(Provider.Openid),
+      expect(getFetchCall(3)).toEqual(
+        authenticationProvidersEndpoint(Provider.Openid)
+      );
+
+      expect(fetchMock.mock.calls[3][1]?.body).toEqual(
         JSON.stringify({
           ...retrievedOpenidConfiguration,
           base_url: 'http://localhost:8081/login',
           groups_mapping: {
             ...retrievedOpenidConfiguration.groups_mapping,
-            relations: [{ contact_group_id: 2, group_value: 'groupValue' }],
+            relations: [{ contact_group_id: 2, group_value: 'groupValue' }]
           },
-          redirect_url: null,
-        }),
-        cancelTokenPutParams,
+          redirect_url: null
+        })
       );
     });
 
     await waitFor(() => {
-      expect(mockedAxios.get).toHaveBeenCalledWith(
-        authenticationProvidersEndpoint(Provider.Openid),
-        cancelTokenRequestParam,
+      expect(getFetchCall(4)).toEqual(
+        authenticationProvidersEndpoint(Provider.Openid)
       );
     });
   });
@@ -410,9 +393,8 @@ describe('Openid configuration form', () => {
     renderOpenidConfigurationForm();
 
     await waitFor(() => {
-      expect(mockedAxios.get).toHaveBeenCalledWith(
-        authenticationProvidersEndpoint(Provider.Openid),
-        cancelTokenRequestParam,
+      expect(getFetchCall(0)).toEqual(
+        authenticationProvidersEndpoint(Provider.Openid)
       );
     });
 
@@ -422,7 +404,7 @@ describe('Openid configuration form', () => {
 
     userEvent.type(
       screen.getByLabelText(labelBaseUrl),
-      '{selectall}{backspace}http://localhost:8081/login',
+      '{selectall}{backspace}http://localhost:8081/login'
     );
     userEvent.tab();
 
@@ -442,7 +424,7 @@ describe('Openid configuration form', () => {
 
     await waitFor(() => {
       expect(screen.getByLabelText(labelBaseUrl)).toHaveValue(
-        'https://localhost:8080',
+        'https://localhost:8080'
       );
     });
   });
@@ -451,15 +433,14 @@ describe('Openid configuration form', () => {
     renderOpenidConfigurationForm();
 
     await waitFor(() => {
-      expect(mockedAxios.get).toHaveBeenCalledWith(
-        authenticationProvidersEndpoint(Provider.Openid),
-        cancelTokenRequestParam,
+      expect(getFetchCall(0)).toEqual(
+        authenticationProvidersEndpoint(Provider.Openid)
       );
     });
 
     await waitFor(() => {
       expect(
-        screen.getByLabelText(labelEmailAttributePath),
+        screen.getByLabelText(labelEmailAttributePath)
       ).toBeInTheDocument();
     });
 
@@ -482,22 +463,22 @@ describe('Openid configuration form', () => {
       retrievedContactTemplates,
       contactTemplatesEndpoint,
       labelContactTemplate,
-      'Contact Template 2',
+      'Contact Template 2'
     ],
     [
       'access group',
       retrievedAccessGroups,
       accessGroupsEndpoint,
       labelAclAccessGroup,
-      'Access Group 2',
+      'Access Group 2'
     ],
     [
       'contact group',
       retrievedContactGroups,
       contactGroupsEndpoint,
       labelContactGroup,
-      'Contact Group 2',
-    ],
+      'Contact Group 2'
+    ]
   ])(
     'updates the %p field when an option is selected from the retrieved options',
     async (_, retrievedOptions, endpoint, label, value) => {
@@ -505,13 +486,12 @@ describe('Openid configuration form', () => {
       renderOpenidConfigurationForm();
 
       mockResponseOnce({
-        data: retrievedOptions,
+        data: retrievedOptions
       });
 
       await waitFor(() => {
-        expect(mockedAxios.get).toHaveBeenCalledWith(
-          authenticationProvidersEndpoint(Provider.Openid),
-          cancelTokenRequestParam,
+        expect(getFetchCall(0)).toEqual(
+          authenticationProvidersEndpoint(Provider.Openid)
         );
       });
 
@@ -524,10 +504,10 @@ describe('Openid configuration form', () => {
       userEvent.click(screen.getByLabelText(label));
 
       await waitFor(() => {
-        expect(getFetchCall(0)).toEqual(
+        expect(getFetchCall(1)).toEqual(
           `${endpoint}?page=1&sort_by=${encodeURIComponent(
-            '{"name":"ASC"}',
-          )}&search=${encodeURIComponent('{"$and":[]}')}`,
+            '{"name":"ASC"}'
+          )}&search=${encodeURIComponent('{"$and":[]}')}`
         );
       });
 
@@ -540,16 +520,15 @@ describe('Openid configuration form', () => {
       await waitFor(() => {
         expect(screen.getAllByLabelText(label)[0]).toHaveValue(value);
       });
-    },
+    }
   );
 
   it('disables the save button when the "Groups mapping" custom endpoint field is cleared', async () => {
     renderOpenidConfigurationForm();
 
     await waitFor(() => {
-      expect(mockedAxios.get).toHaveBeenCalledWith(
-        authenticationProvidersEndpoint(Provider.Openid),
-        cancelTokenRequestParam,
+      expect(getFetchCall(0)).toEqual(
+        authenticationProvidersEndpoint(Provider.Openid)
       );
     });
 
@@ -559,7 +538,7 @@ describe('Openid configuration form', () => {
 
     userEvent.type(
       screen.getByLabelText(labelBaseUrl),
-      '{selectall}{backspace}http://localhost:8081/login',
+      '{selectall}{backspace}http://localhost:8081/login'
     );
 
     await waitFor(() => {
@@ -568,7 +547,7 @@ describe('Openid configuration form', () => {
 
     userEvent.type(
       last(screen.getAllByLabelText(labelDefineYourEndpoint)) as HTMLElement,
-      '{selectall}{backspace}',
+      '{selectall}{backspace}'
     );
 
     await waitFor(() => {
@@ -580,13 +559,12 @@ describe('Openid configuration form', () => {
     renderOpenidConfigurationForm();
 
     mockResponseOnce({
-      data: retrievedContactGroups,
+      data: retrievedContactGroups
     });
 
     await waitFor(() => {
-      expect(mockedAxios.get).toHaveBeenCalledWith(
-        authenticationProvidersEndpoint(Provider.Openid),
-        cancelTokenRequestParam,
+      expect(getFetchCall(0)).toEqual(
+        authenticationProvidersEndpoint(Provider.Openid)
       );
     });
 
@@ -597,10 +575,10 @@ describe('Openid configuration form', () => {
     userEvent.click(screen.getByLabelText(labelContactGroup));
 
     await waitFor(() => {
-      expect(getFetchCall(0)).toEqual(
+      expect(getFetchCall(1)).toEqual(
         `${contactGroupsEndpoint}?page=1&sort_by=${encodeURIComponent(
-          '{"name":"ASC"}',
-        )}&search=${encodeURIComponent('{"$and":[]}')}`,
+          '{"name":"ASC"}'
+        )}&search=${encodeURIComponent('{"$and":[]}')}`
       );
     });
 
@@ -612,7 +590,7 @@ describe('Openid configuration form', () => {
 
     await waitFor(() => {
       expect(screen.getAllByLabelText(labelContactGroup)[0]).toHaveValue(
-        'Contact Group 2',
+        'Contact Group 2'
       );
     });
 
@@ -641,7 +619,7 @@ describe('Openid configuration form', () => {
 
     userEvent.type(
       screen.getAllByLabelText(labelConditionValue)[1],
-      'some text',
+      'some text'
     );
 
     expect(screen.getAllByLabelText(labelConditionValue)).toHaveLength(3);
@@ -655,7 +633,7 @@ describe('Openid configuration form', () => {
 
     userEvent.type(
       screen.getAllByLabelText(labelConditionValue)[1],
-      'some text',
+      'some text'
     );
 
     expect(screen.getAllByLabelText(labelDeleteRelation)).toHaveLength(2);
