@@ -1,15 +1,15 @@
 import { Responsive } from '@visx/visx';
+import { makeStyles } from 'tss-react/mui';
 
 import { Typography, Box } from '@mui/material';
-import makeStyles from '@mui/styles/makeStyles';
 
-const useStyles = makeStyles((theme) => ({
+const useStyles = makeStyles()((theme) => ({
   lineText: {
     fontSize: theme.typography.body2.fontSize,
     overflow: 'hidden',
     textOverflow: 'ellipsis',
-    whiteSpace: 'nowrap',
-  },
+    whiteSpace: 'nowrap'
+  }
 }));
 
 interface Props {
@@ -17,7 +17,7 @@ interface Props {
 }
 
 const DetailsLine = ({ line }: Props): JSX.Element => {
-  const classes = useStyles();
+  const { classes } = useStyles();
 
   return (
     <Responsive.ParentSize parentSizeStyles={{ height: 'auto' }}>
@@ -27,7 +27,7 @@ const DetailsLine = ({ line }: Props): JSX.Element => {
             className={classes.lineText}
             lineHeight={1}
             style={{
-              maxWidth: width || 'unset',
+              maxWidth: width || 'unset'
             }}
           >
             {line}
