@@ -1,101 +1,106 @@
-import { memo, MouseEvent, useEffect, useMemo, useRef, useState } from 'react';
+import {
+  memo,
+  MouseEvent,
+  ReactNode,
+  useEffect,
+  useMemo,
+  useRef,
+  useState
+} from 'react';
 
-import {
-  equals,
-  isNil,
-  identity,
-  min,
-  max,
-  not,
-  lt,
-  gte,
-  difference,
-  lte,
-  length,
-} from 'ramda';
-import {
-  Shape,
-  Grid,
-  Scale,
-  Group,
-  Tooltip as VisxTooltip,
-  Event,
-} from '@visx/visx';
+import { AddSVGProps } from '@visx/shape/lib/types';
+import { Event, Grid, Group, Shape, Tooltip as VisxTooltip } from '@visx/visx';
 import { bisector } from 'd3-array';
-import { ScaleLinear } from 'd3-scale';
-import { useTranslation } from 'react-i18next';
 import { useAtomValue, useSetAtom } from 'jotai';
+import { equals, gte, identity, isNil, lt, not, pick, values } from 'ramda';
+import { useTranslation } from 'react-i18next';
+import { makeStyles } from 'tss-react/mui';
 
 import {
+  alpha,
   Button,
+  CircularProgress,
   ClickAwayListener,
   Paper,
-  Typography,
-  Theme,
-  alpha,
-  useTheme,
-  CircularProgress,
   Tooltip,
+  Typography,
+  useTheme
 } from '@mui/material';
-import makeStyles from '@mui/styles/makeStyles';
 import { grey } from '@mui/material/colors';
 
 import {
   dateTimeFormat,
   useLocaleDateTimeFormat,
-  useMemoComponent,
+  useMemoComponent
 } from '@centreon/ui';
 
-import AnomalyDetectionEnvelopeThreshold from '../AnomalyDetection/AnomalyDetectionEnvelopeThreshold';
-import { TimeValue, Line as LineModel, AdjustTimePeriodProps } from '../models';
-import {
-  getTime,
-  getMin,
-  getMax,
-  getDates,
-  getUnits,
-  getMetricValuesForUnit,
-  getMetricValuesForLines,
-  getSortedStackedLines,
-  getStackedMetricValues,
-  hasUnitStackedLines,
-} from '../timeSeries';
-import Lines from '../Lines';
-import {
-  labelActionNotPermitted,
-  labelAddComment,
-} from '../../../translatedLabels';
-import { TimelineEvent } from '../../../Details/tabs/Timeline/models';
-import { Resource, ResourceType } from '../../../models';
-import { ResourceDetails } from '../../../Details/models';
 import { CommentParameters } from '../../../Actions/api';
 import useAclQuery from '../../../Actions/Resource/aclQuery';
-import memoizeComponent from '../../../memoizedComponent';
-import { CustomFactorsData } from '../AnomalyDetection/models';
+import { ResourceDetails } from '../../../Details/models';
+import { TimelineEvent } from '../../../Details/tabs/Timeline/models';
+import { Resource } from '../../../models';
+import {
+  labelActionNotPermitted,
+  labelAddComment
+} from '../../../translatedLabels';
+import Lines from '../Lines';
+import {
+  AdditionalLines,
+  AdjustTimePeriodProps,
+  Line as LineModel,
+  TimeValue
+} from '../models';
+import {
+  getDates,
+  getLeftScale,
+  getRightScale,
+  getSortedStackedLines,
+  getTime,
+  getUnits,
+  getXScale,
+  getYScale
+} from '../timeSeries';
 
 import AddCommentForm from './AddCommentForm';
 import Annotations from './Annotations';
+import {
+  annotationHoveredAtom,
+  changeAnnotationHoveredDerivedAtom
+} from './annotationsAtoms';
 import Axes from './Axes';
-import TimeShiftZones, {
-  TimeShiftContext,
-  TimeShiftDirection,
-} from './TimeShiftZones';
 import {
   changeMousePositionAndTimeValueDerivedAtom,
   changeTimeValueDerivedAtom,
   MousePosition,
-  mousePositionAtom,
+  mousePositionAtom
 } from './mouseTimeValueAtoms';
-import {
-  annotationHoveredAtom,
-  changeAnnotationHoveredDerivedAtom,
-} from './annotationsAtoms';
+import TimeShiftZones, {
+  TimeShiftContext,
+  TimeShiftDirection
+} from './TimeShiftZones';
+
+interface BarProps {
+  className?: string;
+  innerRef?: React.Ref<SVGRectElement>;
+  open: boolean;
+}
+
+const Bar = ({
+  open,
+  ...restProps
+}: AddSVGProps<BarProps, SVGRectElement>): JSX.Element | null => {
+  if (!open) {
+    return null;
+  }
+
+  return <Shape.Bar {...restProps} />;
+};
 
 const propsAreEqual = (prevProps, nextProps): boolean =>
   equals(prevProps, nextProps);
 
 const MemoizedAxes = memo(Axes, propsAreEqual);
-const MemoizedBar = memo(Shape.Bar, propsAreEqual);
+const MemoizedBar = memo(Bar, propsAreEqual);
 const MemoizedGridColumns = memo(Grid.GridColumns, propsAreEqual);
 const MemoizedGridRows = memo(Grid.GridRows, propsAreEqual);
 const MemoizedLines = memo(Lines, propsAreEqual);
@@ -117,67 +122,68 @@ interface Props {
   xAxisTickFormat: string;
 }
 
-const useStyles = makeStyles<Theme, Pick<Props, 'onAddComment'>>((theme) => ({
-  addCommentButton: {
-    fontSize: 10,
-  },
-  addCommentTooltip: {
-    display: 'grid',
-    fontSize: 10,
-    gridAutoFlow: 'row',
-    justifyItems: 'center',
-    padding: theme.spacing(0.5),
-    position: 'absolute',
-  },
-  container: {
-    '& .visx-axis-bottom': {
-      '& .visx-axis-tick': {
+const useStyles = makeStyles<Pick<Props, 'onAddComment'>>()(
+  (theme, { onAddComment }) => ({
+    addCommentButton: {
+      fontSize: 10
+    },
+    addCommentTooltip: {
+      display: 'grid',
+      fontSize: 10,
+      gridAutoFlow: 'row',
+      justifyItems: 'center',
+      padding: theme.spacing(0.5),
+      position: 'absolute'
+    },
+    container: {
+      '& .visx-axis-bottom': {
+        '& .visx-axis-tick': {
+          '& .visx-line': {
+            stroke: theme.palette.text.primary
+          }
+        }
+      },
+      '& .visx-axis-line': {
+        stroke: theme.palette.text.primary
+      },
+      '& .visx-axis-right': {
+        '& .visx-axis-tick': {
+          '& .visx-line': {
+            stroke: theme.palette.text.primary
+          }
+        }
+      },
+      '& .visx-columns': {
         '& .visx-line': {
-          stroke: theme.palette.text.primary,
-        },
+          stroke: theme.palette.divider
+        }
       },
-    },
-    '& .visx-axis-line': {
-      stroke: theme.palette.text.primary,
-    },
-    '& .visx-axis-right': {
-      '& .visx-axis-tick': {
+      '& .visx-rows': {
         '& .visx-line': {
-          stroke: theme.palette.text.primary,
-        },
+          stroke: theme.palette.divider
+        }
       },
+      fill: theme.palette.text.primary,
+      position: 'relative'
     },
-    '& .visx-columns': {
-      '& .visx-line': {
-        stroke: theme.palette.divider,
-      },
+    graphLoader: {
+      alignItems: 'center',
+      backgroundColor: alpha(theme.palette.common.white, 0.5),
+      display: 'flex',
+      height: '100%',
+      justifyContent: 'center',
+      position: 'absolute',
+      width: '100%'
     },
-    '& .visx-rows': {
-      '& .visx-line': {
-        stroke: theme.palette.divider,
-      },
+    overlay: {
+      cursor: isNil(onAddComment) ? 'normal' : 'crosshair'
     },
-    fill: theme.palette.text.primary,
-    position: 'relative',
-  },
-  graphLoader: {
-    alignItems: 'center',
-    backgroundColor: alpha(theme.palette.common.white, 0.5),
-    display: 'flex',
-    height: '100%',
-    justifyContent: 'center',
-    position: 'absolute',
-    width: '100%',
-  },
-  overlay: {
-    cursor: ({ onAddComment }): string =>
-      isNil(onAddComment) ? 'normal' : 'crosshair',
-  },
-  tooltip: {
-    padding: 12,
-    zIndex: theme.zIndex.tooltip,
-  },
-}));
+    tooltip: {
+      padding: 12,
+      zIndex: theme.zIndex.tooltip
+    }
+  })
+);
 
 interface ZoomBoundaries {
   end: number;
@@ -197,12 +203,12 @@ interface GraphContentProps {
   format: (parameters) => string;
   height: number;
   hideAddCommentTooltip: () => void;
-  isEditAnomalyDetectionDataDialogOpen?: boolean;
+  interactWithGraph: boolean;
   isInViewport?: boolean;
   lines: Array<LineModel>;
   loading: boolean;
   onAddComment?: (commentParameters: CommentParameters) => void;
-  resizeEnvelopeData?: CustomFactorsData;
+  renderAdditionalLines?: (args: AdditionalLines) => ReactNode;
   resource: Resource | ResourceDetails;
   shiftTime?: (direction: TimeShiftDirection) => void;
   showAddCommentTooltip: (args) => void;
@@ -212,23 +218,6 @@ interface GraphContentProps {
   xAxisTickFormat: string;
 }
 
-const getScale = ({
-  values,
-  height,
-  stackedValues,
-}): ScaleLinear<number, number> => {
-  const minValue = min(getMin(values), getMin(stackedValues));
-  const maxValue = max(getMax(values), getMax(stackedValues));
-
-  const upperRangeValue = minValue === maxValue && maxValue === 0 ? height : 0;
-
-  return Scale.scaleLinear<number>({
-    domain: [minValue, maxValue],
-    nice: true,
-    range: [height, upperRangeValue],
-  });
-};
-
 export const bisectDate = bisector(identity).center;
 
 const GraphContent = ({
@@ -254,40 +243,39 @@ const GraphContent = ({
   displayEventAnnotations,
   containsMetrics,
   isInViewport,
-  isEditAnomalyDetectionDataDialogOpen,
+  interactWithGraph,
   displayTimeValues,
-  resizeEnvelopeData,
+  renderAdditionalLines
 }: GraphContentProps): JSX.Element => {
-  const classes = useStyles({ onAddComment });
+  const { classes } = useStyles({ onAddComment });
   const { t } = useTranslation();
+  const theme = useTheme();
 
   const [addingComment, setAddingComment] = useState(false);
   const [commentDate, setCommentDate] = useState<Date>();
   const [zoomPivotPosition, setZoomPivotPosition] = useState<number | null>(
-    null,
+    null
   );
   const [zoomBoundaries, setZoomBoundaries] = useState<ZoomBoundaries | null>(
-    null,
+    null
   );
   const graphSvgRef = useRef<SVGSVGElement | null>(null);
   const { canComment } = useAclQuery();
   const mousePosition = useAtomValue(mousePositionAtom);
   const changeMousePositionAndTimeValue = useSetAtom(
-    changeMousePositionAndTimeValueDerivedAtom,
+    changeMousePositionAndTimeValueDerivedAtom
   );
   const changeTimeValue = useSetAtom(changeTimeValueDerivedAtom);
   const setAnnotationHovered = useSetAtom(annotationHoveredAtom);
   const changeAnnotationHovered = useSetAtom(
-    changeAnnotationHoveredDerivedAtom,
+    changeAnnotationHoveredDerivedAtom
   );
 
-  const theme = useTheme();
-
   const graphWidth = width > 0 ? width - margin.left - margin.right : 0;
   const graphHeight = height > 0 ? height - margin.top - margin.bottom : 0;
 
   const hideAddCommentTooltipOnEspcapePress = (
-    event: globalThis.KeyboardEvent,
+    event: globalThis.KeyboardEvent
   ): void => {
     if (event.key === 'Escape') {
       hideAddCommentTooltip();
@@ -298,72 +286,46 @@ const GraphContent = ({
     document.addEventListener(
       'keydown',
       hideAddCommentTooltipOnEspcapePress,
-      false,
+      false
     );
 
     return (): void => {
       document.removeEventListener(
         'keydown',
         hideAddCommentTooltipOnEspcapePress,
-        false,
+        false
       );
     };
   }, []);
 
   const xScale = useMemo(
     () =>
-      Scale.scaleTime<number>({
-        domain: [
-          getMin(timeSeries.map(getTime)),
-          getMax(timeSeries.map(getTime)),
-        ],
-        range: [0, graphWidth],
+      getXScale({
+        dataTime: timeSeries,
+        valueWidth: graphWidth
       }),
-    [graphWidth, timeSeries],
+    [graphWidth, timeSeries]
   );
 
-  const [firstUnit, secondUnit, thirdUnit] = getUnits(lines);
+  const leftScale = useMemo(
+    () =>
+      getLeftScale({
+        dataLines: lines,
+        dataTimeSeries: timeSeries,
+        valueGraphHeight: graphHeight
+      }),
+    [timeSeries, lines, graphHeight]
+  );
 
-  const leftScale = useMemo(() => {
-    const values = isNil(thirdUnit)
-      ? getMetricValuesForUnit({ lines, timeSeries, unit: firstUnit })
-      : getMetricValuesForLines({ lines, timeSeries });
-
-    const firstUnitHasStackedLines =
-      isNil(thirdUnit) && not(isNil(firstUnit))
-        ? hasUnitStackedLines({ lines, unit: firstUnit })
-        : false;
-
-    const stackedValues = firstUnitHasStackedLines
-      ? getStackedMetricValues({
-          lines: getSortedStackedLines(lines),
-          timeSeries,
-        })
-      : [0];
-
-    return getScale({ height: graphHeight, stackedValues, values });
-  }, [timeSeries, lines, firstUnit, graphHeight]);
-
-  const rightScale = useMemo(() => {
-    const values = getMetricValuesForUnit({
-      lines,
-      timeSeries,
-      unit: secondUnit,
-    });
-
-    const secondUnitHasStackedLines = isNil(secondUnit)
-      ? false
-      : hasUnitStackedLines({ lines, unit: secondUnit });
-
-    const stackedValues = secondUnitHasStackedLines
-      ? getStackedMetricValues({
-          lines: getSortedStackedLines(lines),
-          timeSeries,
-        })
-      : [0];
-
-    return getScale({ height: graphHeight, stackedValues, values });
-  }, [timeSeries, lines, secondUnit, graphHeight]);
+  const rightScale = useMemo(
+    () =>
+      getRightScale({
+        dataLines: lines,
+        dataTimeSeries: timeSeries,
+        valueGraphHeight: graphHeight
+      }),
+    [timeSeries, lines, graphHeight]
+  );
 
   const getTimeValue = (x: number): TimeValue => {
     const date = xScale.invert(x - margin.left);
@@ -376,7 +338,7 @@ const GraphContent = ({
     if (isNil(position)) {
       changeMousePositionAndTimeValue({
         position: null,
-        timeValue: null,
+        timeValue: null
       });
 
       return;
@@ -389,7 +351,7 @@ const GraphContent = ({
   const displayTooltip = (event: MouseEvent<SVGRectElement>): void => {
     const { x, y } = Event.localPoint(
       graphSvgRef.current as SVGSVGElement,
-      event,
+      event
     ) || { x: 0, y: 0 };
 
     const mouseX = x - margin.left;
@@ -399,13 +361,13 @@ const GraphContent = ({
       mouseX,
       resourceId: resource.uuid,
       timeline,
-      xScale,
+      xScale
     });
 
     if (zoomPivotPosition) {
       setZoomBoundaries({
         end: gte(mouseX, zoomPivotPosition) ? mouseX : zoomPivotPosition,
-        start: lt(mouseX, zoomPivotPosition) ? mouseX : zoomPivotPosition,
+        start: lt(mouseX, zoomPivotPosition) ? mouseX : zoomPivotPosition
       });
       changeTimeValue({ isInViewport, newTimeValue: null });
 
@@ -442,7 +404,7 @@ const GraphContent = ({
     if (zoomBoundaries?.start !== zoomBoundaries?.end) {
       applyZoom?.({
         end: xScale.invert(zoomBoundaries?.end || graphWidth),
-        start: xScale.invert(zoomBoundaries?.start || 0),
+        start: xScale.invert(zoomBoundaries?.start || 0)
       });
 
       return;
@@ -459,7 +421,7 @@ const GraphContent = ({
 
     showAddCommentTooltip({
       tooltipLeft: displayLeft ? x - commentTooltipWidth : x,
-      tooltipTop: y,
+      tooltipTop: y
     });
   };
 
@@ -484,7 +446,7 @@ const GraphContent = ({
     setZoomPivotPosition(mouseX);
     setZoomBoundaries({
       end: mouseX,
-      start: mouseX,
+      start: mouseX
     });
     hideAddCommentTooltip();
   };
@@ -495,7 +457,7 @@ const GraphContent = ({
   const mousePositionY = (position?.[1] || 0) - margin.top;
 
   const zoomBarWidth = Math.abs(
-    (zoomBoundaries?.end || 0) - (zoomBoundaries?.start || 0),
+    (zoomBoundaries?.end || 0) - (zoomBoundaries?.start || 0)
   );
 
   const mousePositionTimeTick = position
@@ -508,25 +470,18 @@ const GraphContent = ({
 
   const commentTitle = isCommentPermitted ? '' : t(labelActionNotPermitted);
 
-  const stackedLines = getSortedStackedLines(lines);
-
-  const regularLines = difference(lines, stackedLines);
-
-  const isLegendClicked = lte(length(lines), 1);
-
-  const isDisplayedThreshold =
-    equals(resource?.type, ResourceType.anomalydetection) && !isLegendClicked;
-
-  const thresholdProps = {
+  const additionalLinesProps = {
+    getSortedStackedLines,
     getTime,
+    getUnits,
+    getYScale,
     graphHeight,
+    graphWidth,
     leftScale,
-    regularLines,
+    lines,
     rightScale,
-    secondUnit,
-    thirdUnit,
     timeSeries,
-    xScale,
+    xScale
   };
 
   return (
@@ -558,9 +513,6 @@ const GraphContent = ({
               base={base}
               graphHeight={graphHeight}
               graphWidth={graphWidth}
-              isEditAnomalyDetectionDataDialogOpen={
-                isEditAnomalyDetectionDataDialogOpen
-              }
               leftScale={leftScale}
               lines={lines}
               rightScale={rightScale}
@@ -568,32 +520,20 @@ const GraphContent = ({
               xScale={xScale}
             />
             <MemoizedLines
-              anomalyDetectionEnvelope={
-                isDisplayedThreshold && (
-                  <AnomalyDetectionEnvelopeThreshold {...thresholdProps} />
-                )
-              }
-              anomalyDetectionResizeEnvelope={
-                resizeEnvelopeData?.isResizing &&
-                isDisplayedThreshold && (
-                  <AnomalyDetectionEnvelopeThreshold
-                    {...thresholdProps}
-                    data={resizeEnvelopeData}
-                  />
-                )
-              }
               displayTimeValues={displayTimeValues}
               graphHeight={graphHeight}
-              isEditAnomalyDetectionDataDialogOpen={
-                isEditAnomalyDetectionDataDialogOpen
-              }
               leftScale={leftScale}
               lines={lines}
+              renderAdditionalLines={renderAdditionalLines?.({
+                additionalLinesProps,
+                resource
+              })}
               rightScale={rightScale}
               timeSeries={timeSeries}
               timeTick={timeTick}
               xScale={xScale}
             />
+
             {displayEventAnnotations && (
               <MemoizedAnnotations
                 graphHeight={graphHeight}
@@ -602,9 +542,11 @@ const GraphContent = ({
                 xScale={xScale}
               />
             )}
+
             <MemoizedBar
               fill={alpha(theme.palette.primary.main, 0.2)}
               height={graphHeight}
+              open={interactWithGraph}
               stroke={alpha(theme.palette.primary.main, 0.5)}
               width={zoomBarWidth}
               x={zoomBoundaries?.start || 0}
@@ -612,10 +554,7 @@ const GraphContent = ({
             />
             {useMemoComponent({
               Component:
-                displayTimeValues &&
-                containsMetrics &&
-                position &&
-                !isEditAnomalyDetectionDataDialogOpen ? (
+                displayTimeValues && containsMetrics && position ? (
                   <g>
                     <Shape.Line
                       from={{ x: mousePositionX, y: 0 }}
@@ -635,22 +574,21 @@ const GraphContent = ({
                 ) : (
                   <g />
                 ),
-              memoProps: [mousePosition],
+              memoProps: [mousePosition]
             })}
-            {!isEditAnomalyDetectionDataDialogOpen && (
-              <MemoizedBar
-                className={classes.overlay}
-                fill="transparent"
-                height={graphHeight}
-                width={graphWidth}
-                x={0}
-                y={0}
-                onMouseDown={displayZoomPreview}
-                onMouseLeave={closeTooltip}
-                onMouseMove={displayTooltip}
-                onMouseUp={displayAddCommentTooltip}
-              />
-            )}
+            <MemoizedBar
+              className={classes.overlay}
+              fill="transparent"
+              height={graphHeight}
+              open={interactWithGraph}
+              width={graphWidth}
+              x={0}
+              y={0}
+              onMouseDown={displayZoomPreview}
+              onMouseLeave={closeTooltip}
+              onMouseMove={displayTooltip}
+              onMouseUp={displayAddCommentTooltip}
+            />
           </Group.Group>
           <TimeShiftContext.Provider
             value={useMemo(
@@ -661,7 +599,7 @@ const GraphContent = ({
                 loading,
                 marginLeft: margin.left,
                 marginTop: margin.top,
-                shiftTime,
+                shiftTime
               }),
               [
                 canAdjustTimePeriod,
@@ -669,26 +607,26 @@ const GraphContent = ({
                 graphWidth,
                 loading,
                 margin,
-                shiftTime,
-              ],
+                shiftTime
+              ]
             )}
           >
             <TimeShiftZones />
           </TimeShiftContext.Provider>
         </svg>
-        {addCommentTooltipOpen && !isEditAnomalyDetectionDataDialogOpen && (
+        {addCommentTooltipOpen && (
           <Paper
             className={classes.addCommentTooltip}
             style={{
               left: addCommentTooltipLeft,
               top: addCommentTooltipTop,
-              width: commentTooltipWidth,
+              width: commentTooltipWidth
             }}
           >
             <Typography variant="caption">
               {format({
                 date: new Date(commentDate as Date),
-                formatString: dateTimeFormat,
+                formatString: dateTimeFormat
               })}
             </Typography>
             <Tooltip title={commentTitle}>
@@ -706,7 +644,7 @@ const GraphContent = ({
             </Tooltip>
           </Paper>
         )}
-        {addingComment && !isEditAnomalyDetectionDataDialogOpen && (
+        {addingComment && (
           <AddCommentForm
             date={commentDate as Date}
             resource={resource}
@@ -721,7 +659,7 @@ const GraphContent = ({
   );
 };
 
-const memoProps = [
+const propertiesToMemoize = [
   'addCommentTooltipLeft',
   'addCommentTooltipTop',
   'addCommentTooltipOpen',
@@ -738,15 +676,9 @@ const memoProps = [
   'displayTooltipValues',
   'displayEventAnnotations',
   'containsMetrics',
-  'isInViewport',
-  'resizeEnvelopeData',
+  'isInViewport'
 ];
 
-const MemoizedGraphContent = memoizeComponent<GraphContentProps>({
-  Component: GraphContent,
-  memoProps,
-});
-
 const Graph = (
   props: Omit<
     GraphContentProps,
@@ -758,7 +690,7 @@ const Graph = (
     | 'format'
     | 'changeMetricsValue'
     | 'isInViewport'
-  >,
+  >
 ): JSX.Element => {
   const { format } = useLocaleDateTimeFormat();
   const {
@@ -766,20 +698,25 @@ const Graph = (
     tooltipTop: addCommentTooltipTop,
     tooltipOpen: addCommentTooltipOpen,
     showTooltip: showAddCommentTooltip,
-    hideTooltip: hideAddCommentTooltip,
+    hideTooltip: hideAddCommentTooltip
   } = VisxTooltip.useTooltip();
 
-  return (
-    <MemoizedGraphContent
-      {...props}
-      addCommentTooltipLeft={addCommentTooltipLeft}
-      addCommentTooltipOpen={addCommentTooltipOpen}
-      addCommentTooltipTop={addCommentTooltipTop}
-      format={format}
-      hideAddCommentTooltip={hideAddCommentTooltip}
-      showAddCommentTooltip={showAddCommentTooltip}
-    />
-  );
+  const memoProps = pick(propertiesToMemoize, props);
+
+  return useMemoComponent({
+    Component: (
+      <GraphContent
+        {...props}
+        addCommentTooltipLeft={addCommentTooltipLeft}
+        addCommentTooltipOpen={addCommentTooltipOpen}
+        addCommentTooltipTop={addCommentTooltipTop}
+        format={format}
+        hideAddCommentTooltip={hideAddCommentTooltip}
+        showAddCommentTooltip={showAddCommentTooltip}
+      />
+    ),
+    memoProps: [...values(memoProps)]
+  });
 };
 
 export default Graph;
