@@ -10,13 +10,13 @@ const rowColorConditions = (theme: Theme): Array<Condition> => [
   {
     color: theme.palette.action.inDowntimeBackground,
     condition: ({ in_downtime }): boolean => in_downtime,
-    name: 'inDowntime',
+    name: 'inDowntime'
   },
   {
     color: theme.palette.action.acknowledgedBackground,
     condition: ({ acknowledged }): boolean => acknowledged,
-    name: 'acknowledged',
-  },
+    name: 'acknowledged'
+  }
 ];
 
 export { rowColorConditions };
