@@ -504,8 +504,7 @@ $tpl->display("formGenerateFiles.ihtml");
         divErrors.style.visibility = 'hidden';
         tdEl2.appendChild(divErrors);
         for (var i = 0; i < errors.length; i++) {
-            divErrors.innerHTML += errors.get(i).firstChild.data;
-            divErrors.innerHTML += "<br/>";
+            divErrors.innerHTML += errors.get(i).firstChild.data + "<br/>";
         }
     }
 
