@@ -205,7 +205,7 @@ $DBRESULT->closeCursor();
 /**
  * Template / Style for Quickform input
  */
-$attrsText = array("size" => "30");
+$attrsText = ["size" => "30"];
 $attrsText2 = array("size" => "60");
 $attrsTextDescr = array("size" => "80");
 $attrsTextMail = array("size" => "90");
@@ -317,16 +317,51 @@ $form->addElement('header', 'acl', _("Access lists"));
  * Don't change contact name, alias or autologin key in massive change
  */
 if ($o != MASSIVE_CHANGE) {
+    /**
+     * Contact name attributes
+     */
+    $attrsTextDescr["id"] = "contact_name";
+    $attrsTextDescr["data-testid"] = "contact_name";
     $form->addElement('text', 'contact_name', _("Full Name"), $attrsTextDescr);
+
+    /**
+     * Contact alias attributes
+     */
+    $attrsText["id"] = "contact_alias";
+    $attrsText["data-testid"] = "contact_alias";
     $form->addElement('text', 'contact_alias', _("Alias / Login"), $attrsText);
-    $form->addElement('text', 'contact_autologin_key', _("Autologin Key"), array("size" => "90", "id" => "aKey"));
+
+    $form->addElement(
+        'text',
+        'contact_autologin_key',
+        _("Autologin Key"),
+        [
+            "size" => "90",
+            "id" => "aKey",
+            "data-testid" => "aKey"
+        ]
+    );
     $form->addElement(
         'button',
         'contact_gen_akey',
         _("Generate"),
-        ['onclick' => "generatePassword('aKey', '$encodedPasswordPolicy');"]
+        [
+            'onclick' => "generatePassword('aKey', '$encodedPasswordPolicy');",
+            "id" => "generateAutologinKeyButton",
+            "data-testid" => "generateAutologinKeyButton"
+        ]
     );
+    /**
+     * Contact email attributes
+     */
+    $attrsTextMail["id"] = "contact_email";
+    $attrsTextMail["data-testid"] = "contact_email";
     $form->addElement('text', 'contact_email', _("Email"), $attrsTextMail);
+    /**
+     * Contact Pager attributes
+     */
+    $attrsText["id"] = "contact_pager";
+    $attrsText["data-testid"] = "contact_pager";
     $form->addElement('text', 'contact_pager', _("Pager"), $attrsText);
 }
 
@@ -334,15 +369,22 @@ if ($o != MASSIVE_CHANGE) {
 /**
  * Contact template used
  */
-$form->addElement('select', 'contact_template_id', _("Contact template used"), $contactTpl);
-
+$form->addElement(
+    'select',
+    'contact_template_id',
+    _("Contact template used"),
+    $contactTpl,
+    [
+        "id" => "contact_template_id",
+        "data-testid" => "contact_template_id"
+    ]
+);
 $form->addElement('header', 'furtherAddress', _("Additional Addresses"));
-$form->addElement('text', 'contact_address1', _("Address1"), $attrsText);
-$form->addElement('text', 'contact_address2', _("Address2"), $attrsText);
-$form->addElement('text', 'contact_address3', _("Address3"), $attrsText);
-$form->addElement('text', 'contact_address4', _("Address4"), $attrsText);
-$form->addElement('text', 'contact_address5', _("Address5"), $attrsText);
-$form->addElement('text', 'contact_address6', _("Address6"), $attrsText);
+for ($i=0; $i < 6; $i++) {
+    $attrsText["id"] = "contact_address" . $i + 1;
+    $attrsText["data-testid"] = "contact_address" . $i + 1;
+    $form->addElement('text', 'contact_address' . $i+1, _("Address" . $i + 1), $attrsText);
+}
 
 /**
  * Contact Groups Field
@@ -363,15 +405,41 @@ $attrContactgroup1 = array_merge(
     $attrContactgroups,
     array('defaultDatasetRoute' => $defaultDatasetRoute)
 );
-$form->addElement('select2', 'contact_cgNotif', _("Linked to Contact Groups"), [], $attrContactgroup1);
+$form->addElement(
+    'select2',
+    'contact_cgNotif',
+    _("Linked to Contact Groups"),
+    [],
+    $attrContactgroup1
+);
 
 /**
  * Contact Centreon information
  */
 $form->addElement('header', 'oreon', _("Centreon"));
 $tab = [];
-$tab[] = $form->createElement('radio', 'contact_oreon', null, _("Yes"), '1');
-$tab[] = $form->createElement('radio', 'contact_oreon', null, _("No"), '0');
+$tab[] = $form->createElement(
+    'radio',
+    'contact_oreon',
+    null,
+    _("Yes"),
+    '1',
+    [
+        "id" => "contact_oreon_yes",
+        "data-testid" => "contact_oreon_yes"
+    ]
+);
+$tab[] = $form->createElement(
+    'radio',
+    'contact_oreon',
+    null,
+    _("No"),
+    '0',
+    [
+        "id" => "contact_oreon_no",
+        "data-testid" => "contact_oreon_no"
+    ]
+);
 $form->addGroup($tab, 'contact_oreon', _("Reach Centreon Front-end"), '&nbsp;');
 
 if ($o !== MASSIVE_CHANGE) {
@@ -379,33 +447,188 @@ if ($o !== MASSIVE_CHANGE) {
         'password',
         'contact_passwd',
         _("Password"),
-        array(
+        [
             "size" => "30",
             "autocomplete" => "new-password",
             "id" => "passwd1",
+            "data-testid" => "passwd1",
             "onkeypress" => "resetPwdType(this);"
-        )
+        ]
     );
     $form->addElement(
         'password',
         'contact_passwd2',
         _("Confirm Password"),
-        array(
+        [
             "size" => "30",
             "autocomplete" => "new-password",
             "id" => "passwd2",
+            "data-testid" => "passwd2",
             "onkeypress" => "resetPwdType(this);"
-        )
+        ]
     );
     $form->addElement(
         'button',
         'contact_gen_passwd',
         _("Generate"),
-        ['onclick' => "generatePassword('passwd', '$encodedPasswordPolicy');"]
+        [
+            'onclick' => "generatePassword('passwd', '$encodedPasswordPolicy');",
+            "id" => "contact_gen_passwd",
+            "data-testid" => "contact_gen_passwd"
+        ]
     );
 }
 
-$form->addElement('select', 'contact_lang', _("Default Language"), $langs);
+/* ------------------------ Topoogy ---------------------------- */
+$pages = [null => ""];
+$aclUser = $centreon->user->lcaTStr;
+if (! empty($aclUser)) {
+    $acls = array_flip(explode(',', $aclUser));
+    /**
+     * Transform [1, 2, 101, 202, 10101, 20201] to :
+     *
+     * 1
+     *   101
+     *     10101
+     * 2
+     *   202
+     *     20201
+     */
+    $createTopologyTree = function (array $topologies): array {
+        ksort($topologies, \SORT_ASC);
+        $parentsLvl = [];
+
+        // Classify topologies by parents
+        foreach (array_keys($topologies) as $page) {
+            if (strlen($page) === 1) {
+                // MENU level 1
+                if (! array_key_exists($page, $parentsLvl)) {
+                    $parentsLvl[$page] = [];
+                }
+            } elseif (strlen($page) === 3) {
+                // MENU level 2
+                $parentLvl1 = substr($page, 0, 1);
+                if (! array_key_exists($parentLvl1, $parentsLvl)) {
+                    $parentsLvl[$parentLvl1] = [];
+                }
+                if (! array_key_exists($page, $parentsLvl[$parentLvl1])) {
+                    $parentsLvl[$parentLvl1][$page] = [];
+                }
+            } elseif (strlen($page) === 5) {
+                // MENU level 3
+                $parentLvl1 = substr($page, 0, 1);
+                $parentLvl2 = substr($page, 0, 3);
+                if (! array_key_exists($parentLvl1, $parentsLvl)) {
+                    $parentsLvl[$parentLvl1] = [];
+                }
+                if (! array_key_exists($parentLvl2, $parentsLvl[$parentLvl1])) {
+                    $parentsLvl[$parentLvl1][$parentLvl2] = [];
+                }
+                if (! in_array($page, $parentsLvl[$parentLvl1][$parentLvl2])) {
+                    $parentsLvl[$parentLvl1][$parentLvl2][] = $page;
+                }
+            }
+        }
+
+        return $parentsLvl;
+    };
+
+    /**
+     * Check if at least one child can be shown
+     */
+    $oneChildCanBeShown = function () use (&$childrenLvl3, &$translatedPages): bool {
+        foreach ($childrenLvl3 as $topologyPage) {
+            if ($translatedPages[$topologyPage]['show']) {
+                return true;
+            }
+        }
+        return false;
+    };
+
+    $topologies = $createTopologyTree($acls);
+
+    /**
+     * Retrieve the name of all topologies available for this user
+     */
+    $aclTopologies = $pearDB->query(
+        "SELECT topology_page, topology_name, topology_show "
+        . "FROM topology "
+        . "WHERE topology_page IN ($aclUser)"
+    );
+
+    $translatedPages = [];
+
+    while ($topology = $aclTopologies->fetch(\PDO::FETCH_ASSOC)) {
+        $translatedPages[$topology['topology_page']] = [
+            'i18n' => _($topology['topology_name']),
+            'show' => ((int)$topology['topology_show'] === 1)
+        ];
+    }
+
+    /**
+     * Create flat tree for menu with the topologies names
+     * [item1Id] = menu1 > submenu1 > item1
+     * [item2Id] = menu2 > submenu2 > item2
+     */
+    foreach ($topologies as $parentLvl1 => $childrenLvl2) {
+        $parentNameLvl1 = $translatedPages[$parentLvl1]['i18n'];
+        foreach ($childrenLvl2 as $parentLvl2 => $childrenLvl3) {
+            $parentNameLvl2 = $translatedPages[$parentLvl2]['i18n'];
+            $isThirdLevelMenu = false;
+            $parentLvl3 = null;
+
+            if ($oneChildCanBeShown()) {
+                /**
+                 * There is at least one child that can be shown then we can
+                 * process the third level
+                 */
+                foreach ($childrenLvl3 as $parentLvl3) {
+                    if ($translatedPages[$parentLvl3]['show']) {
+                        $parentNameLvl3 = $translatedPages[$parentLvl3]['i18n'];
+
+                        if ($parentNameLvl2 === $parentNameLvl3) {
+                            /**
+                             * The name between lvl2 and lvl3 are equals.
+                             * We keep only lvl1 and lvl3
+                             */
+                            $pages[$parentLvl3] = $parentNameLvl1 . ' > '
+                                . $parentNameLvl3;
+                        } else {
+                            $pages[$parentLvl3] = $parentNameLvl1 . ' > '
+                                . $parentNameLvl2 . ' > '
+                                . $parentNameLvl3;
+                        }
+                    }
+                }
+
+                $isThirdLevelMenu = true;
+            }
+
+            // select parent from level 2 if level 3 is missing
+            $pageId = $parentLvl3 ?? $parentLvl2;
+
+            if (! $isThirdLevelMenu && $translatedPages[$pageId]['show']) {
+                /**
+                 * We show only first and second level
+                 */
+                $pages[$pageId] =
+                    $parentNameLvl1 . ' > ' . $parentNameLvl2;
+            }
+        }
+    }
+}
+
+$form->addElement(
+    'select',
+    'contact_lang',
+    _("Default Language"),
+    $langs,
+    [
+        "id" => "contact_lang",
+        "data-testid" => "contact_lang"
+    ]
+);
+$form->addElement('select', 'default_page', _("Default page"), $pages);
 $form->addElement(
     'select',
     'contact_type_msg',
@@ -415,18 +638,60 @@ $form->addElement(
 
 if ($centreon->user->admin) {
     $tab = array();
-    $tab[] = $form->createElement('radio', 'contact_admin', null, _("Yes"), '1');
-    $tab[] = $form->createElement('radio', 'contact_admin', null, _("No"), '0');
+    $tab[] = $form->createElement(
+        'radio',
+        'contact_admin',
+        null,
+        _("Yes"),
+        '1',
+        ["id" => "contact_admin_yes", "data-testid" => "contact_admin_yes"]
+    );
+    $tab[] = $form->createElement(
+        'radio',
+        'contact_admin',
+        null,
+        _("No"),
+        '0',
+        ["id" => "contact_admin_no", "data-testid" => "contact_admin_no"]
+    );
     $form->addGroup($tab, 'contact_admin', _("Admin"), '&nbsp;');
 
     $tab = array();
-    $tab[] = $form->createElement('radio', 'reach_api', null, _("Yes"), '1');
-    $tab[] = $form->createElement('radio', 'reach_api', null, _("No"), '0');
+    $tab[] = $form->createElement(
+            'radio',
+            'reach_api',
+            null,
+            _("Yes"),
+            '1',
+            ["id" => "reach_api_yes", "data-testid" => "reach_api_yes"]
+        );
+    $tab[] = $form->createElement(
+        'radio',
+        'reach_api',
+        null,
+        _("No"),
+        '0',
+        ["id" => "reach_api_no", "data-testid" => "reach_api_no"]
+    );
     $form->addGroup($tab, 'reach_api', _("Reach API Configuration"), '&nbsp;');
 
     $tab = array();
-    $tab[] = $form->createElement('radio', 'reach_api_rt', null, _("Yes"), '1');
-    $tab[] = $form->createElement('radio', 'reach_api_rt', null, _("No"), '0');
+    $tab[] = $form->createElement(
+            'radio',
+            'reach_api_rt',
+            null,
+            _("Yes"),
+            '1',
+            ["id" => "reach_api_rt_yes", "data-testid" => "reach_api_rt_yes"]
+        );
+    $tab[] = $form->createElement(
+        'radio',
+        'reach_api_rt',
+        null,
+        _("No"),
+        '0',
+        ["id" => "reach_api_rt_no", "data-testid" => "reach_api_rt_no"]
+    );
     $form->addGroup($tab, 'reach_api_rt', _("Reach API Realtime"), '&nbsp;');
 }
 
@@ -447,7 +712,13 @@ $attrAclgroup1 = array_merge(
     $attrAclgroups,
     array('defaultDatasetRoute' => $defaultDatasetRoute)
 );
-$form->addElement('select2', 'contact_acl_groups', _("Access list groups"), array(), $attrAclgroup1);
+$form->addElement(
+    'select2',
+    'contact_acl_groups',
+    _("Access list groups"),
+    [],
+    $attrAclgroup1,
+);
 
 /**
  * Include GMT Class
@@ -467,7 +738,13 @@ $attrTimezones = array(
     'multiple' => false,
     'linkedObject' => 'centreonGMT'
 );
-$form->addElement('select2', 'contact_location', _("Timezone / Location"), array(), $attrTimezones);
+$form->addElement(
+    'select2',
+    'contact_location',
+    _("Timezone / Location"),
+    [],
+    $attrTimezones
+);
 
 if ($o != MASSIVE_CHANGE) {
     $auth_type = array();
@@ -478,6 +755,11 @@ if ($o != MASSIVE_CHANGE) {
 $auth_type["local"] = "Centreon";
 if ($centreon->optGen['ldap_auth_enable'] == 1) {
     $auth_type["ldap"] = "LDAP";
+    /**
+     * LDAP Distinguished Name attributes
+     */
+    $attrsText2["id"] = "contact_ldap_dn";
+    $attrsText2["data-testid"] = "contact_ldap_dn";
     $dnElement = $form->addElement('text', 'contact_ldap_dn', _("LDAP DN (Distinguished Name)"), $attrsText2);
     if (!$centreon->user->admin) {
         $dnElement->freeze();
@@ -491,7 +773,16 @@ if ($o != MASSIVE_CHANGE) {
         'reach_api_rt' => ['reach_api_rt' => '0']
     ]);
 }
-$form->addElement('select', 'contact_auth_type', _("Authentication Source"), $auth_type);
+$form->addElement(
+    'select',
+    'contact_auth_type',
+    _("Authentication Source"),
+    $auth_type,
+    [
+        "id" => "contact_auth_type",
+        "data-testid" => "contact_auth_type"
+    ]
+);
 
 /**
  * Notification informations
@@ -499,9 +790,33 @@ $form->addElement('select', 'contact_auth_type', _("Authentication Source"), $au
 $form->addElement('header', 'notification', _("Notification"));
 
 $tab = [];
-$tab[] = $form->createElement('radio', 'contact_enable_notifications', null, _("Yes"), '1');
-$tab[] = $form->createElement('radio', 'contact_enable_notifications', null, _("No"), '0');
-$tab[] = $form->createElement('radio', 'contact_enable_notifications', null, _("Default"), '2');
+$tab[] = $form->createElement(
+    'radio',
+    'contact_enable_notifications',
+    null,
+    _("Yes"),
+    '1',
+    ["data-testid" => "contact_enable_notifications_yes"]
+);
+$tab[] = $form->createElement(
+    'radio',
+    'contact_enable_notifications',
+    null,
+    _("No"),
+    '0',
+    ["data-testid" => "contact_enable_notifications_no"]
+);
+$tab[] = $form->createElement(
+    'radio',
+    'contact_enable_notifications',
+    null,
+    _("Default"),
+    '2',
+    [
+        "id" => "contact_enable_notifications_default",
+        "data-testid" => "contact_enable_notifications_default"
+    ]
+);
 $form->addGroup($tab, 'contact_enable_notifications', _("Enable Notifications"), '&nbsp;');
 if ($o != MASSIVE_CHANGE) {
     $form->setDefaults(array('contact_enable_notifications' => '2'));
@@ -516,42 +831,42 @@ $hostNotifOpt[] = $form->createElement(
     'd',
     '&nbsp;',
     _("Down"),
-    array('id' => 'hDown', 'onClick' => 'uncheckAllH(this);')
+    array('id' => 'hDown', 'onClick' => 'uncheckAllH(this);', "data-testid" => "hDown")
 );
 $hostNotifOpt[] = $form->createElement(
     'checkbox',
     'u',
     '&nbsp;',
     _("Unreachable"),
-    array('id' => 'hUnreachable', 'onClick' => 'uncheckAllH(this);')
+    array('id' => 'hUnreachable', 'onClick' => 'uncheckAllH(this);', "data-testid" => "hUnreachable")
 );
 $hostNotifOpt[] = $form->createElement(
     'checkbox',
     'r',
     '&nbsp;',
     _("Recovery"),
-    array('id' => 'hRecovery', 'onClick' => 'uncheckAllH(this);')
+    array('id' => 'hRecovery', 'onClick' => 'uncheckAllH(this);', "data-testid" => "hRecovery")
 );
 $hostNotifOpt[] = $form->createElement(
     'checkbox',
     'f',
     '&nbsp;',
     _("Flapping"),
-    array('id' => 'hFlapping', 'onClick' => 'uncheckAllH(this);')
+    array('id' => 'hFlapping', 'onClick' => 'uncheckAllH(this);', "data-testid" => "hFlapping")
 );
 $hostNotifOpt[] = $form->createElement(
     'checkbox',
     's',
     '&nbsp;',
     _("Downtime Scheduled"),
-    array('id' => 'hScheduled', 'onClick' => 'uncheckAllH(this);')
+    array('id' => 'hScheduled', 'onClick' => 'uncheckAllH(this);', "data-testid" => "hScheduled")
 );
 $hostNotifOpt[] = $form->createElement(
     'checkbox',
     'n',
     '&nbsp;',
     _("None"),
-    array('id' => 'hNone', 'onClick' => 'javascript:uncheckAllH(this);')
+    array('id' => 'hNone', 'onClick' => 'javascript:uncheckAllH(this);', "data-testid" => "hNone")
 );
 $form->addGroup($hostNotifOpt, 'contact_hostNotifOpts', _("Host Notification Options"), '&nbsp;&nbsp;');
 
@@ -561,7 +876,13 @@ $attrTimeperiod1 = array_merge(
     $attrTimeperiods,
     array('defaultDatasetRoute' => $defaultDatasetRoute)
 );
-$form->addElement('select2', 'timeperiod_tp_id', _("Host Notification Period"), array(), $attrTimeperiod1);
+$form->addElement(
+    'select2',
+    'timeperiod_tp_id',
+    _("Host Notification Period"),
+    [],
+    $attrTimeperiod1
+);
 
 
 unset($hostNotifOpt);
@@ -585,7 +906,13 @@ $attrCommand1 = array_merge(
         'availableDatasetRoute' => $availableDatasetRoute
     )
 );
-$form->addElement('select2', 'contact_hostNotifCmds', _("Host Notification Commands"), array(), $attrCommand1);
+$form->addElement(
+    'select2',
+    'contact_hostNotifCmds',
+    _("Host Notification Commands"),
+    [],
+    $attrCommand1
+);
 
 /** * *****************************
  * Service notifications
@@ -596,49 +923,49 @@ $svNotifOpt[] = $form->createElement(
     'w',
     '&nbsp;',
     _("Warning"),
-    array('id' => 'sWarning', 'onClick' => 'uncheckAllS(this);')
+    array('id' => 'sWarning', 'onClick' => 'uncheckAllS(this);', "data-testid" => "sWarning")
 );
 $svNotifOpt[] = $form->createElement(
     'checkbox',
     'u',
     '&nbsp;',
     _("Unknown"),
-    array('id' => 'sUnknown', 'onClick' => 'uncheckAllS(this);')
+    array('id' => 'sUnknown', 'onClick' => 'uncheckAllS(this);', "data-testid" => "sUnknown")
 );
 $svNotifOpt[] = $form->createElement(
     'checkbox',
     'c',
     '&nbsp;',
     _("Critical"),
-    array('id' => 'sCritical', 'onClick' => 'uncheckAllS(this);')
+    array('id' => 'sCritical', 'onClick' => 'uncheckAllS(this);', "data-testid" => "sCritical")
 );
 $svNotifOpt[] = $form->createElement(
     'checkbox',
     'r',
     '&nbsp;',
     _("Recovery"),
-    array('id' => 'sRecovery', 'onClick' => 'uncheckAllS(this);')
+    array('id' => 'sRecovery', 'onClick' => 'uncheckAllS(this);', "data-testid" => "sRecovery")
 );
 $svNotifOpt[] = $form->createElement(
     'checkbox',
     'f',
     '&nbsp;',
     _("Flapping"),
-    array('id' => 'sFlapping', 'onClick' => 'uncheckAllS(this);')
+    array('id' => 'sFlapping', 'onClick' => 'uncheckAllS(this);', "data-testid" => "sFlapping")
 );
 $svNotifOpt[] = $form->createElement(
     'checkbox',
     's',
     '&nbsp;',
     _("Downtime Scheduled"),
-    array('id' => 'sScheduled', 'onClick' => 'uncheckAllS(this);')
+    array('id' => 'sScheduled', 'onClick' => 'uncheckAllS(this);', "data-testid" => "sScheduled")
 );
 $svNotifOpt[] = $form->createElement(
     'checkbox',
     'n',
     '&nbsp;',
     _("None"),
-    array('id' => 'sNone', 'onClick' => 'uncheckAllS(this);')
+    array('id' => 'sNone', 'onClick' => 'uncheckAllS(this);', "data-testid" => "sNone")
 );
 $form->addGroup($svNotifOpt, 'contact_svNotifOpts', _("Service Notification Options"), '&nbsp;&nbsp;');
 
@@ -650,7 +977,13 @@ $attrTimeperiod2 = array_merge(
     $attrTimeperiods,
     array('defaultDatasetRoute' => $defaultAttrTimeperiod2Route)
 );
-$form->addElement('select2', 'timeperiod_tp_id2', _("Service Notification Period"), array(), $attrTimeperiod2);
+$form->addElement(
+    'select2',
+    'timeperiod_tp_id2',
+    _("Service Notification Period"),
+    [],
+    $attrTimeperiod2
+);
 
 if ($o == MASSIVE_CHANGE) {
     $mc_mod_svcmds = array();
@@ -672,14 +1005,34 @@ $attrCommand2 = array_merge(
         'availableDatasetRoute' => $availableCommand2Route
     )
 );
-$form->addElement('select2', 'contact_svNotifCmds', _("Service Notification Commands"), array(), $attrCommand2);
+$form->addElement(
+    'select2',
+    'contact_svNotifCmds',
+    _("Service Notification Commands"),
+    [],
+    $attrCommand2
+);
 
 /**
  * Further informations
  */
 $form->addElement('header', 'furtherInfos', _("Additional Information"));
-$cctActivation[] = $form->createElement('radio', 'contact_activate', null, _("Enabled"), '1');
-$cctActivation[] = $form->createElement('radio', 'contact_activate', null, _("Disabled"), '0');
+$cctActivation[] = $form->createElement(
+    'radio',
+    'contact_activate',
+    null,
+    _("Enabled"),
+    '1',
+    ["id" => "contact_activate_enable", "data-testid" => "contact_activate_enable"]
+);
+$cctActivation[] = $form->createElement(
+    'radio',
+    'contact_activate',
+    null,
+    _("Disabled"),
+    '0',
+    ["id" => "contact_activate_disable", "data-testid" => "contact_activate_disable"]
+);
 $form->addGroup($cctActivation, 'contact_activate', _("Status"), '&nbsp;');
 $form->setDefaults(array('contact_activate' => '1'));
 if ($o == MODIFY_CONTACT && $centreon->user->get_id() == $cct["contact_id"]) {
@@ -688,7 +1041,11 @@ if ($o == MODIFY_CONTACT && $centreon->user->get_id() == $cct["contact_id"]) {
 
 $form->addElement('hidden', 'contact_register');
 $form->setDefaults(array('contact_register' => '1'));
-
+/**
+ * Comments attributes
+ */
+$attrsTextarea["id"] = "contact_comment";
+$attrsTextarea["data-testid"] = "contact_comment";
 $form->addElement('textarea', 'contact_comment', _("Comments"), $attrsTextarea);
 
 $form->addElement('hidden', 'contact_id');
