@@ -86,7 +86,7 @@ $authorized_actions = [
     "service_notifications" => "",
     "service_event_handler" => "",
     "service_flap_detection" => "",
-    "service_obsess" => "",
+    "global_service_obsess" => "",
     "service_acknowledgement" => "",
     "service_disacknowledgement" => "",
 ];
@@ -242,7 +242,7 @@ if (!is_null($host_id)) {
         $shiStatement->bindValue(":hostId", (int) $host_id, \PDO::PARAM_INT);
         $shiStatement->bindValue(":serviceId", (int) $service_id, \PDO::PARAM_INT);
         $shiStatement->execute();
-        $tab_status_service = array(0 => "OK", 1 => "WARNING", 2 => "CRITICAL", "3" => "UNKNOWN", "4" => "PENDING");
+        $tab_status_service = array(0 => "OK", 1 => "WARNING", 2 => "CRITICAL", 3 => "UNKNOWN", 4 => "PENDING");
         $tab_class_service = array(
             "ok" => 'service_ok',
             "warning" => 'service_warning',
@@ -304,10 +304,13 @@ if (!is_null($host_id)) {
             if (isset($data['performance_data'])) {
                 $data['performance_data'] = $data['performance_data'];
             }
+            if ($data["current_state"] === null || !in_array($data["current_state"], array_keys($tab_status_service))) {
+                $data["current_state"] = 4; // default to PENDING
+            }
             if ($data["service_description"] == $svc_description) {
                 $service_status = $data;
             }
-            if (!isset($tab_status[$data["current_state"]])) {
+            if (!isset($tab_status[$tab_status_service[$data["current_state"]]])) {
                 $tab_status[$tab_status_service[$data["current_state"]]] = 0;
             }
             $tab_status[$tab_status_service[$data["current_state"]]]++;
@@ -331,21 +334,6 @@ if (!is_null($host_id)) {
             $service_status["current_state"] = $tab_status_service[$service_status["current_state"]];
         }
 
-        /*
-         * start ndo host detail
-         */
-        $tab_host_status[0] = "UP";
-        $tab_host_status[1] = "DOWN";
-        $tab_host_status[2] = "UNREACHABLE";
-
-        $rq2 = "SELECT state AS current_state FROM hosts WHERE name LIKE '" . $pearDBO->escape($host_name) . "'";
-        $DBRESULT = $pearDBO->query($rq2);
-
-        $ndo2 = $DBRESULT->fetchRow();
-        if ($ndo2 !== false && $ndo2["current_state"] <= 2) {
-            $host_status[$host_name] = $tab_host_status[$ndo2["current_state"]];
-        }
-
         // Get Host informations
         $hStatement = $pearDB->prepare("SELECT * FROM host WHERE host_id = :hostId");
         $hStatement->bindValue(":hostId", (int)$host_id, \PDO::PARAM_INT);
@@ -752,9 +740,6 @@ if (!is_null($host_id)) {
         if (isset($host_id) && isset($service_id)) {
             $tpl->assign("flag_graph", $centreonGraph->statusGraphExists($host_id, $service_id));
         }
-        if (isset($host_status) && isset($host_status[$host_name])) {
-            $tpl->assign("host_data", $host_status[$host_name]);
-        }
         $tpl->assign("service_data", $service_status);
         $tpl->assign("host_display_name", CentreonUtils::escapeSecure($hostNameDisplay));
         $tpl->assign("host_name", CentreonUtils::escapeSecure($host_name));
@@ -966,7 +951,7 @@ if (!is_null($host_id)) {
             "<?php echo $img_en[1];?>"
         );
 
-        labels['service_obsess'] = new Array(
+        labels['global_service_obsess'] = new Array(
             "<?php echo $str_obsess_svc_enable;?>",
             "<?php echo $str_obsess_svc_disable;?>",
             "<?php echo $img_en[0];?>",
@@ -1027,7 +1012,7 @@ if (!is_null($host_id)) {
                 "service_event_handler",
                 "service_flap_detection",
                 "service_passive_checks",
-                "service_obsess"
+                "global_service_obsess"
             );
 
             if (state == "0") {
