@@ -145,8 +145,8 @@ $form->addElement('textarea', 'rpn_function', _("RPN (Reverse Polish Notation) F
 $form->addElement(
     'static',
     'rpn_text',
-    _("<br><i><b><font color=\"#B22222\">Notes </font>:</b></i><br>&nbsp;&nbsp;&nbsp;- " .
-        "Do not mix metrics of different sources.<br>&nbsp;&nbsp;&nbsp;- " .
+    _("<br><i><b><font color=\"#B22222\">Notes </font>:</b></i><br>- " .
+        "Do not mix metrics of different sources.<br>- " .
         "Only aggregation functions work in VDEF rpn expressions.")
 );
 #$form->addElement('select', 'real_metrics', null, $rmetrics);
